/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "advanced_options_dialog.h"

#include <cassert>

#include <qpushbutton.h>
#include <qtimer.h>

#include <kapp.h>
#include <kconfig.h>
#include <klocale.h>




AdvancedOptionsDialog::AdvancedOptionsDialog(QWidget * parent, char const * name, bool modal,
                                             QString const & caption, int buttonMask,
                                             ButtonCode defaultButton, bool separator,
                                             QString const & user1, QString const & user2,
                                             QString const & user3) :
    KDialogBase(parent, name, modal, caption, buttonMask, defaultButton, separator, user1, user2, user3),
    m_advanced_button(0)
{
}


QPushButton * AdvancedOptionsDialog::createAdvancedOptionsButton(QWidget * parent)
{
    delete m_advanced_button;
    m_advanced_button = 0;

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    if (!config->readBoolEntry("Always show advanced options", false))
    {
        m_advanced_button = new QPushButton(i18n("Show advanced options"), parent);
        m_advanced_button->setMaximumSize(m_advanced_button->sizeHint());
        connect(m_advanced_button, SIGNAL(clicked()), this, SLOT(changeAdvanced()));
    }

    return m_advanced_button;
}


void AdvancedOptionsDialog::addAdvancedWidget(QWidget * widget)
{
    assert(widget != 0);

    if (m_advanced_button == 0)
    {
        return;
    }

    m_advanced_widgets.push_back(widget);
    widget->hide();
}


void AdvancedOptionsDialog::changeAdvanced()
{
    if (m_advanced_widgets.empty())
    {
        return;
    }

    int const nr_of_widgets = static_cast<int> (m_advanced_widgets.size());

    if (m_advanced_widgets.front()->isVisible())
    {
        for (int i = 0; i < nr_of_widgets; ++i)
        {
            m_advanced_widgets[i]->hide();
        }

        m_advanced_button->setText(i18n("Show advanced options"));
        QTimer::singleShot(0, this, SLOT(callResize()));
    }
    else
    {
        for (int i = 0; i < nr_of_widgets; ++i)
        {
            m_advanced_widgets[i]->show();
        }

        m_advanced_button->setText(i18n("Hide advanced options"));
    }

    m_advanced_button->setMaximumSize(m_advanced_button->sizeHint());
}


void AdvancedOptionsDialog::callResize()
{
    resize(width(), 1);
}
