/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_ADVANCED_OPTIONS_DIALOG_INC_GUARD_H
#define EASYSOK_ADVANCED_OPTIONS_DIALOG_INC_GUARD_H


#include <kdialogbase.h>

#include <vector>


class QPushButton;
class QTimer;




/**
 * Adds the capability to show/hide advanced options to KDialogBase.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class AdvancedOptionsDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Creates the dialog.
     *
     * @param parent Parent of the dialog.
     * @param name Dialog name (for internal use only)
     * @param modal Controls dialog modality. If false, the rest of the program interface
     *              (example: other dialogs) is accessible while the dialog is open.
     * @param caption The dialog caption. Do not specify the application name here.
     *                The class will take care of that.
     * @param buttonMask Specifies which buttons will be visible. If zero (0) no button box will be made.
     * @param defaultButton Specifies which button will be marked as the default.
     * @param separator If true, a separator line is drawn between the action buttons and the main widget.
     * @param user1 User button1 text.
     * @param user2 User button2 text.
     * @param user3 User button3 text.
     */

    AdvancedOptionsDialog(QWidget * parent = 0, char const * name = 0, bool modal = true,
                          QString const & caption = QString::null, int buttonMask = Ok | Apply | Cancel,
                          ButtonCode defaultButton = Ok, bool separator = false,
                          QString const & user1 = QString::null, QString const & user2 = QString::null,
                          QString const & user3 = QString::null);


    /**
     * Creates the advanced options button.
     *
     * @param parent The parent of the button.
     * @return A pointer to the button (may be 0).
     */

    QPushButton * createAdvancedOptionsButton(QWidget * parent);


    /**
     * Adds the widgets to the widget used for the advanced options.
     *
     * Should be called only after createAdvancedOptionsButton() was called before.
     *
     * @param widget The widget to add.
     */

    void addAdvancedWidget(QWidget * widget);


private slots:

    /**
     * Is called,  when show/hide advanced is clicked.
     */

    void changeAdvanced();


    /**
     * Calls resize.
     */

    void callResize();


private:

    /**
     * The show/hide advanced options dialog.
     */

    QPushButton * m_advanced_button;


    /**
     * The advanced options widgets.
     */

    std::vector<QWidget *> m_advanced_widgets;
};


#endif
