/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "atomic_move.h"

#include <cassert>

#include <klocale.h>




QPoint const AtomicMove::s_diffs[4] =
{
    QPoint(-1, 0),
    QPoint(1, 0),
    QPoint(0, -1),
    QPoint(0, 1)
};


AtomicMove::AtomicMove(AtomicMoveType type) :
    m_type(type)
{
}


AtomicMove::AtomicMoveType AtomicMove::type() const
{
    return m_type;
}


QPoint const & AtomicMove::diff() const
{
    assert(m_type >= 0);
    assert(m_type < 4);

    return s_diffs[m_type];
}


QString AtomicMove::toText() const
{
    QString result;

    switch (m_type)
    {
    case LEFT:
        result = i18n("left");
        break;

    case RIGHT:
        result = i18n("right");
        break;

    case UP:
        result = i18n("up");
        break;

    case DOWN:
        result = i18n("down");
        break;

    default:
        assert(false);
    }

    return result;
}
