/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_ATOMIC_MOVE_INC_GUARD_H
#define EASYSOK_ATOMIC_MOVE_INC_GUARD_H


#include <qpoint.h>
#include <qstring.h>




/**
 * This class represents an atomic move of the keeper or a gem.
 *
 * An atomic move is a move one field left, right, up or down.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 * @see Move
 */

class AtomicMove
{

public:

    /**
     * Defines codes for atomic moves.
     */

    enum AtomicMoveType
    {

        /**
         * An atomic move left.
         */

        LEFT,


        /**
         * An atomic move right.
         */

        RIGHT,


        /**
         * An atomic move up.
         */

        UP,


        /**
         * An atomic move down.
         */

        DOWN
    };


    /**
     * Constructs the atomic move from an AtomicMoveType.
     *
     * @param type The type of the move.
     */

    AtomicMove(AtomicMoveType type);


    /**
     * Returns the AtomicMoveType.
     */

    AtomicMoveType type() const;


    /**
     * Returns a point which represents the atomic move.
     *
     * For AtomicMove::LEFT we return QPoint(-1, 0).
     * For AtomicMove::RIGHT we return QPoint(1, 0).
     * For AtomicMove::UP we return QPoint(0, -1).
     * For AtomicMove::DOWN we return QPoint(0, 1).
     */

    QPoint const & diff() const;


    /**
     * Returns a human readable representation of the atomic move.
     */

    QString toText() const;


private:

    /**
     * The atomic move type.
     */

    AtomicMoveType m_type;


    /**
     * The diffs for the four directions.
     */

    static QPoint const s_diffs[4];
};


#endif
