/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_COLLECTION_COMPARER_INC_GUARD_H
#define EASYSOK_COLLECTION_COMPARER_INC_GUARD_H


class Collection;




/**
 * This class compares two collections.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class CollectionComparer
{

public:

    /**
     * Creates the object.
     * @param collection1 The first collection.
     * @param collection2 The second collection.
     */

    CollectionComparer(Collection const & collection1, Collection const & collection2);


    /**
     * Returns true, if both collections are absolutely equal.
     */

    bool areEqual() const;


    /**
     * Returns true, if the collections are absolutely unrelated.
     */

    bool areUnrelated() const;


    /**
     * Returns true, if only trivial changes are found (difficulty, copyright, info or author changed).
     */

    bool onlyTrivialChanges() const;


    /**
     * Returns true, if only the name of the collection is changed.
     */

    bool onlyCollectionNameChanged() const;


    /**
     * Returns true, if the first collection adds levels to the second collection.
     */

    bool addsLevels() const;


    /**
     * Returns true, if the first collection removes levels from the second collection.
     */

    bool removesLevels() const;


    /**
     * Returns true, if the first collection changes properties of the second collection.
     */

    bool changesProperties() const;


    /**
     * Returns true, if the first collection reorders properties of the second collection.
     */

    bool reordersLevels() const;


    /**
     * Returns true, if the current collection comparerer found a
     * worser equality than the given comparer.
     *
     * @param other The other comparer.
     */

    bool operator < (CollectionComparer const & other) const;


private:

    /**
     * The number of reordered levels.
     */

    int m_nr_reordered;


    /**
     * The number of removed levels.
     */

    int m_nr_removed;


    /**
     * The number of added levels.
     */

    int m_nr_added;


    /**
     * The collections are equal.
     */

    bool m_are_equal;


    /**
     * The collections are unrelated.
     */

    bool m_are_unrelated;


    /**
     * The collection only has another name.
     */

    bool m_only_collection_name_changed;


    /**
     * The first collection adds levels.
     */

    bool m_adds_levels;


    /**
     * The first collection removes levels.
     */

    bool m_removes_levels;


    /**
     * The first collection changes properties.
     */

    bool m_changes_properties;


    /**
     * The first collection reorders levels.
     */

    bool m_reorders_levels;


    /**
     * Not trivial changes are found.
     */

    bool m_not_trivial_changes;
};


#endif

