/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_COLLECTION_PROPERTIES_DIALOG_INC_GUARD_H
#define EASYSOK_COLLECTION_PROPERTIES_DIALOG_INC_GUARD_H


#include <kdialogbase.h>

#include <qstring.h>


class KLineEdit;
class Collection;
class QComboBox;
class QMultiLineEdit;




/**
 * Lets the user edit the properties (name, author, etc.) of a collection.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class CollectionPropertiesDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Contructs the object.
     *
     * @param collection The collection for which to edit the properties.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    CollectionPropertiesDialog(Collection const & collection, QWidget * parent = 0, const char * name = 0);


    /**
     * Returns the new author of the collection.
     */

    QString author() const;


    /**
     * Returns the new homepage of the collection.
     */

    QString homepage() const;


    /**
     * Returns the new copyright of the collection.
     */

    QString copyright() const;


    /**
     * Returns the new name of the collection.
     */

    QString name() const;


    /**
     * Returns the new info of the collection.
     */

    QString info() const;


    /**
     * Returns the new difficulty of the collection.
     */

    int difficulty() const;


private:

    /**
     * The new author of the collection.
     */

    KLineEdit * m_author;


    /**
     * The new homepage of the collection.
     */

    KLineEdit * m_hompage;


    /**
     * The new copyright of the collection.
     */

    KLineEdit * m_copyright;


    /**
     * The new name of the collection.
     */
    KLineEdit * m_name;


    /**
     * The new infor of the collection.
     */

    QMultiLineEdit * m_info;


    /**
     * The difficulty.
     */

    QComboBox * m_difficulty;
};


#endif
