/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "compare_solution_dialog.h"

#include <qlabel.h>

#include <klocale.h>




CompareSolutionDialog::CompareSolutionDialog(int my_pushmin_pushes, int my_pushmin_moves,
                                             int my_linearmin_pushes, int my_linearmin_moves,
                                             int my_gemchanges_pushes, int my_gemchanges_moves,
                                             int my_movemin_pushes, int my_movemin_moves,
                                             int best_pushmin_pushes, int best_pushmin_moves,
                                             int best_linearmin_pushes, int best_linearmin_moves,
                                             int best_gemchanges_pushes, int best_gemchanges_moves,
                                             int best_movemin_pushes, int best_movemin_moves,
                                             int nr_solutions, int better_pushes, int equal_pushes,
                                             int better_linear_pushes, int equal_linear_pushes,
                                             int better_gem_changes, int equal_gem_changes,
                                             int better_moves, int equal_moves,
                                             QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Compare Best Solution"), Help | Ok, Ok, true)
{
    int const worser_pushes = nr_solutions - better_pushes - equal_pushes;
    int const worser_linear_pushes = nr_solutions - better_linear_pushes - equal_linear_pushes;
    int const worser_gem_changes = nr_solutions - better_gem_changes - equal_gem_changes;
    int const worser_moves = nr_solutions - better_moves - equal_moves;

    QString nr_solutions_text = i18n("Overall %1 user(s) have solved this level.").arg(nr_solutions);
    QString push_optimal_text = i18n("Push optimal solution");
    QString linear_push_optimal_text = i18n("Linear push optimal solution");
    QString gem_changes_optimal_text = i18n("Gem changes optimal solution");
    QString move_optimal_text = i18n("Move optimal solution");
    QString rank_text = i18n("Rank");
    QString push_rank_text = QString::number(1 + better_pushes);
    QString linear_push_rank_text = QString::number(1 + better_linear_pushes);
    QString gem_changes_rank_text = QString::number(1 + better_gem_changes);
    QString move_rank_text = QString::number(1 + better_moves);
    QString your_solution_text = i18n("Your solution");
    QString pushmin_text = i18n("%1 pushes, %2 moves").arg(my_pushmin_pushes).arg(my_pushmin_moves);
    QString linear_pushmin_text = i18n("%1 pushes, %2 moves").arg(my_linearmin_pushes).arg(my_linearmin_moves);
    QString gem_changes_text = i18n("%1 gem changes, %2 moves");
    gem_changes_text = gem_changes_text.arg(my_gemchanges_pushes).arg(my_gemchanges_moves);
    QString movemin_text = i18n("%1 pushes, %2 moves").arg(my_movemin_pushes).arg(my_movemin_moves);
    QString best_solution_text = i18n("Global best solution");
    QString best_pushmin_text = i18n("%1 pushes, %2 moves").arg(best_pushmin_pushes).arg(best_pushmin_moves);
    QString best_linearmin_text = i18n("%1 pushes, %2 moves");
    best_linearmin_text = best_linearmin_text.arg(best_linearmin_pushes).arg(best_linearmin_moves);
    QString best_gemchanges_text = i18n("%1 gem changes, %2 moves");
    best_gemchanges_text = best_gemchanges_text.arg(best_gemchanges_pushes).arg(best_gemchanges_moves);
    QString best_movemin_text = i18n("%1 pushes, %2 moves").arg(best_movemin_pushes).arg(best_movemin_moves);
    QString better_solutions_text = i18n("Nr. of better solutions");
    QString better_pushes_text = i18n("%1 (%2 percent)").arg(better_pushes);
    better_pushes_text = better_pushes_text.arg(100.0 * better_pushes / nr_solutions);
    QString better_linear_pushes_text = i18n("%1 (%2 percent)").arg(better_linear_pushes);
    better_linear_pushes_text = better_linear_pushes_text.arg(100.0 * better_linear_pushes / nr_solutions);
    QString better_gem_changes_text = i18n("%1 (%2 percent)").arg(better_gem_changes);
    better_gem_changes_text = better_gem_changes_text.arg(100.0 * better_gem_changes / nr_solutions);
    QString better_moves_text = i18n("%1 (%2 percent)").arg(better_moves);
    better_moves_text = better_moves_text.arg(100.0 * better_moves / nr_solutions);
    QString equal_solutions_text = i18n("Nr. of equal solutions");
    QString equal_pushes_text = i18n("%1 (%2 percent)").arg(equal_pushes - 1);
    equal_pushes_text = equal_pushes_text.arg(100.0 * (equal_pushes - 1) / nr_solutions);
    QString equal_linear_pushes_text = i18n("%1 (%2 percent)").arg(equal_linear_pushes - 1);
    equal_linear_pushes_text = equal_linear_pushes_text.arg(100.0 * (equal_linear_pushes - 1) / nr_solutions);
    QString equal_gem_changes_text = i18n("%1 (%2 percent)").arg(equal_gem_changes - 1);
    equal_gem_changes_text = equal_gem_changes_text.arg(100 * (equal_gem_changes - 1) / nr_solutions);
    QString equal_moves_text = i18n("%1 (%2 percent)").arg(equal_moves - 1);
    equal_moves_text = equal_moves_text.arg(100.0 * (equal_moves - 1) / nr_solutions);
    QString worser_solutions_text = i18n("Nr. of worser solutions");
    QString worser_pushes_text = i18n("%1 (%2 percent)").arg(worser_pushes);
    worser_pushes_text = worser_pushes_text.arg(100.0 * worser_pushes / nr_solutions);
    QString worser_linear_pushes_text = i18n("%1 (%2 percent)").arg(worser_linear_pushes);
    worser_linear_pushes_text = worser_linear_pushes_text.arg(100.0 * worser_linear_pushes / nr_solutions);
    QString worser_gem_changes_text = i18n("%1 (%2 percent)").arg(worser_gem_changes);
    worser_gem_changes_text = worser_gem_changes_text.arg(100.0 * worser_gem_changes / nr_solutions);
    QString worser_moves_text = i18n("%1 (%2 percent)").arg(worser_moves);
    worser_moves_text = worser_moves_text.arg(100.0 * worser_moves / nr_solutions);

    QString text = "<qt><p><b>" + nr_solutions_text + "</b></p>"
                   "<table border><tr><th></th><th>" + push_optimal_text + "</th>"
                   "<th>" + linear_push_optimal_text + "</th>"
                   "<th>" + gem_changes_optimal_text + "</th>"
                   "<th>" + move_optimal_text + "</th></tr><tr>"
                   "<td>" + rank_text + "</td>"
                   "<td>" + push_rank_text + "</td>"
                   "<td>" + linear_push_rank_text + "</td>"
                   "<td>" + gem_changes_rank_text + "</td>"
                   "<td>" + move_rank_text + "</td></tr><tr>"
                   "<td>" + your_solution_text + "</td>"
                   "<td>" + pushmin_text + "</td>"
                   "<td>" + linear_pushmin_text + "</td>"
                   "<td>" + gem_changes_text + "</td>"
                   "<td>" + movemin_text + "</td></tr><tr>"
                   "<td>" + best_solution_text + "</td>"
                   "<td>" + best_pushmin_text + "</td>"
                   "<td>" + best_linearmin_text + "</td>"
                   "<td>" + best_gemchanges_text + "</td>"
                   "<td>" + best_movemin_text + "</td></tr><tr>"
                   "<td>" + better_solutions_text + "</td>"
                   "<td>" + better_pushes_text + "</td>"
                   "<td>" + better_linear_pushes_text + "</td>"
                   "<td>" + better_gem_changes_text + "</td>"
                   "<td>" + better_moves_text + "</td></tr><tr>"
                   "<td>" + equal_solutions_text + "</td>"
                   "<td>" + equal_pushes_text + "</td>"
                   "<td>" + equal_linear_pushes_text + "</td>"
                   "<td>" + equal_gem_changes_text + "</td>"
                   "<td>" + equal_moves_text + "</td></tr><tr>"
                   "<td>" + worser_solutions_text + "</td>"
                   "<td>" + worser_pushes_text + "</td>"
                   "<td>" + worser_linear_pushes_text + "</td>"
                   "<td>" + worser_gem_changes_text + "</td>"
                   "<td>" + worser_moves_text + "</td></tr></table></qt>";

    setMainWidget(new QLabel(text, this));

    setHelp("compare-solution-dialog");
}
