/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_COMPRESSED_MOVEMENTS_INC_GUARD_H
#define EASYSOK_COMPRESSED_MOVEMENTS_INC_GUARD_H


#include <vector>

#include <qglobal.h>

#include "move.h"


class Movements;
class QDataStream;




/**
 * This class is a compressed version of Movements.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 * @see move
 */

class CompressedMovements
{

public:

    /**
     * Contructs the object from movements.
     *
     * @param movements The movements to use.
     */

    CompressedMovements(Movements const & movements);


    /**
     * Reads the object from a stream.
     *
     * @param stream The stream to use.
     */

    CompressedMovements(QDataStream & stream);


    /**
     * Returns the number of moves.
     */

    int numberOfMoves() const;


    /**
     * Fills the given vector with the moves.
     *
     * @param moves The vector to fill.
     */

    void setMoves(std::vector<Move> & moves) const;


    /**
     * Writes the movements to a stream.
     *
     * @param stream The stream to use.
     */

    void writeToStream(QDataStream & stream) const;


private:

    /**
     * Here we store the moves.
     */

    std::vector<Q_UINT32> m_moves;


    /**
     * The number of moves.
     */

    int m_number_of_moves;
};


#endif
