/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef EASYSOK_CREATE_SOLUTIONS_DIALOG_INC_GUARD_H
#define EASYSOK_CREATE_SOLUTIONS_DIALOG_INC_GUARD_H


#include <vector>

#include <qmessagebox.h>
#include <qregexp.h>
#include <qstring.h>


class QTimer;




/**
 * The dialog shown when create the solutions to export.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class CreateSolutionsDialog : public QMessageBox
{
    Q_OBJECT

public:

    /**
     * Creates the dialog.
     *
     * @param collections The indices of the collections.
     * @param levels The indices of the levels.
     * @param regexp The solution regexp.
     * @param only_best If true, only the best solutions are created.
     * @param parent The parent of the dialog.
     * @param name The internal name of the dialog.
     */

    CreateSolutionsDialog(std::vector<int> const & collections, std::vector<int> const & levels,
                          QString const regexp, bool only_best, QWidget * parent = 0, char const * name = 0);


    /**
     * Returns the solutions.
     */

    QString solutions() const;


    /**
     * Returns true if the solutions were finished.
     */

    bool finished() const;


public slots:

    /**
     * Creates a solution for the current level.
     */

    void createSolutions();


private:

    /**
     * The collection indices.
     */

    std::vector<int> m_collections;


    /**
     * The level indices.
     */

    std::vector<int> m_levels;


    /**
     * The acutal level.
     */

    int m_level;


    /**
     * Use regexp?
     */

    bool m_use_regexp;


    /**
     * The regexp.
     */

    QRegExp m_regexp;


    /**
     * Only the best?
     */

    bool m_only_best;


    /**
     * The timer.
     */

    QTimer * m_timer;


    /**
     * The solutions.
     */

    QString m_solutions;
};


#endif
