/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "delete_by_name_dialog.h"

#include <cassert>

#include <qdialog.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <klineedit.h>
#include <klocale.h>
#include <kmessagebox.h>

#include <kparts/componentfactory.h>
#include <kregexpeditorinterface.h>




DeleteByNameDialog::DeleteByNameDialog(QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Delete solutions"), Ok | Cancel | Help, Ok, true)
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    QString const old_regexp = config->readEntry("Delete solutions by name regexp", "");

    QVBox * page = makeVBoxMainWidget();

    new QLabel(i18n("Enter a regular expression for the solutions to delete"), page);

    QHBox * page2 = new QHBox(page);
    page2->setSpacing(10);

    m_regexp = new KLineEdit(old_regexp, page2);

    QPushButton * button = new QPushButton(i18n("Start RegExp Editor"), page2);
    connect(button, SIGNAL(clicked()), this, SLOT(showRegExpEditor()));

    setHelp("delete-by-name-dialog");
}


DeleteByNameDialog::~DeleteByNameDialog()
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    config->writeEntry("Delete solutions by name regexp", m_regexp->text());
}


QString DeleteByNameDialog::regExp() const
{
    return m_regexp->text();
}


void DeleteByNameDialog::showRegExpEditor()
{
    QDialog * dialog;
    dialog = KParts::ComponentFactory::createInstanceFromQuery<QDialog>("KRegExpEditor/KRegExpEditor");

    if (dialog)
    {
        if (KMessageBox::questionYesNo(this, i18n("The editor may crash EasySok!\n"
                                                  "Do you want to continue?"),
                                       i18n("Procceed?")) == KMessageBox::No)
        {
            return;
        }

        KRegExpEditorInterface * editor = dynamic_cast<KRegExpEditorInterface *>(editor);
        assert(editor != 0);

        QString regexp = m_regexp->text();
        editor->setRegExp(regexp);

        if (dialog->exec())
        {
            m_regexp->setText(editor->regExp());
        }
    }
    else
    {
        KMessageBox::error(this, i18n("You must have the kdeutils package installed "
                                      "to get the regular expression editor!"));
    }
}
