/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "dom_helper.h"

#include <algorithm>

#include <qdom.h>




QRgb DomHelper::getColor(QDomElement const & dom_element)
{
    int red = dom_element.attribute("red", "0").toInt();
    red = std::max(std::min(red, 255), 0);
    int green = dom_element.attribute("green", "0").toInt();
    green = std::max(std::min(green, 255), 0);
    int blue = dom_element.attribute("blue", "0").toInt();
    blue = std::max(std::min(blue, 255), 0);
    int alpha = dom_element.attribute("alpha", "255").toInt();
    alpha = std::max(std::min(alpha, 255), 0);

    return qRgba(red, green, blue, alpha);
}


int DomHelper::getInteger(QDomElement const & dom_element, QString const & name, int default_value)
{
    if (dom_element.hasAttribute(name))
    {
        return dom_element.attribute(name).toInt();
    }
    else
    {
        return default_value;
    }
}


double DomHelper::getDouble(QDomElement const & dom_element, QString const & name, double default_value)
{
    if (dom_element.hasAttribute(name))
    {
        return dom_element.attribute(name).toDouble();
    }
    else
    {
        return default_value;
    }
}
