/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_DOM_HELPER_INC_GUARD_H
#define EASYSOK_DOM_HELPER_INC_GUARD_H


#include <qcolor.h>


class QDomElement;
class QString;




/**
 * This class has some convinient functions for handling DOM documents.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class DomHelper
{
public:

    /**
     * Returns the color specified in the attributes of the DOM element.
     *
     * @param dom_element The DOM element to use.
     */

    static QRgb getColor(QDomElement const & dom_element);


    /**
     * Returns the integer value specified in the attributes of the DOM element.
     *
     * @param dom_element The DOM element to use.
     * @param name The name of the attribute.
     * @param default_value The default value returned, when the attribute is not found.
     */

    static int getInteger(QDomElement const & dom_element, QString const & name, int default_value);


    /**
     * Returns the double value specified in the attributes of the DOM element.
     *
     * @param dom_element The DOM element to use.
     * @param name The name of the attribute.
     * @param default_value The default value returned, when the attribute is not found.
     */

    static double getDouble(QDomElement const & dom_element, QString const & name, double default_value);
};


#endif
