/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "duplicate_level_finder.h"

#include <cassert>
#include <utility>

#include <klocale.h>

#include "collection.h"
#include "collection_holder.h"
#include "map.h"




DuplicateLevelFinder::DuplicateLevelFinder() :
    m_number_of_collections(CollectionHolder::numberOfCollections()),
    m_collection_nr(0),
    m_collection(CollectionHolder::collection(0)),
    m_number_of_levels(m_collection->numberOfLevels()),
    m_level_nr(0)
{
    m_steps = 1;

    for (int i = 0; i < m_number_of_collections; ++i)
    {
        m_steps += CollectionHolder::collection(i)->numberOfLevels();
    }
}


bool DuplicateLevelFinder::process()
{
    Map map = m_collection->level(m_level_nr).map().simplify();
    bool is_dup = false;

    for (int i = 0; i < 16; ++i)
    {
        if ((i & 3 ) == 0)
        {
            map.mirrorHorizontally();
        }

        if ((i & 7) == 0)
        {
            map.mirrorVertically();
        }

        map.rotateRight();
        map.setKeeperToFirstReachable();

        std::map<CompressedMap, int>::const_iterator it = maps.find(CompressedMap(map));

        if (it != maps.end())
        {
            int collection_nr = it->second / 65536;
            int level_nr = it->second & 65535;

            QString text_to_add = i18n("Level Nr. %1 of '%2' equals level Nr. %3 of '%4'.\n");
            text_to_add = text_to_add.arg(m_level_nr + 1).arg(m_collection->name()).arg(level_nr + 1);
            text_to_add = text_to_add.arg(CollectionHolder::collection(collection_nr)->name());

            m_text += text_to_add;

            is_dup = true;

            break;
        }
    }

    if (!is_dup)
    {
        maps.insert(std::make_pair(CompressedMap(map), m_collection_nr * 65536 + m_level_nr));
    }

    ++m_level_nr;

    if (m_level_nr == m_number_of_levels)
    {
        m_level_nr = 0;
        ++m_collection_nr;

        if (m_collection_nr == m_number_of_collections)
        {
            return true;
        }
        else
        {
            m_collection = CollectionHolder::collection(m_collection_nr);
            m_number_of_levels = m_collection->numberOfLevels();
        }
    }

    return false;
}


int DuplicateLevelFinder::steps() const
{
    return m_steps;
}


bool DuplicateLevelFinder::finished() const
{
    return m_collection_nr == m_number_of_collections;
}


bool DuplicateLevelFinder::foundDuplicates() const
{
    assert(finished());

    return m_text.isEmpty();
}


QString const & DuplicateLevelFinder::text() const
{
    assert(finished());

    return m_text;
}
