/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_DUPLICATE_LEVEL_FINDER_INC_GUARD_H
#define EASYSOK_DUPLICATE_LEVEL_FINDER_INC_GUARD_H


#include <map>

#include <qstring.h>

#include "compressed_map.h"


class Collection;




/**
 * Used to find duplicate levels in the CollectionHolder.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class DuplicateLevelFinder
{

public:

    /**
     * Creates the object.
     */

    DuplicateLevelFinder();


    /**
     * Call this as long as it returns false.
     */

    bool process();


    /**
     * Returns the number of steps needed.
     */

    int steps() const;


    /**
     * Returns true, if the search was finished (process() returned true).
     */

    bool finished() const;


    /**
     * Returns true, if duplicate levels are found.
     */

    bool foundDuplicates() const;


    /**
     * Returns a string containing the duplicate levels.
     */

    QString const & text() const;


private:

    /**
     * The number of collections.
     */

    int m_number_of_collections;


    /**
     * The actual collection nr.
     */

    int m_collection_nr;


    /**
     * The actual collection.
     */

    Collection * m_collection;


    /**
     * The actual number of levels.
     */

    int m_number_of_levels;


    /**
     * The actual level nr.
     */

    int m_level_nr;


    /**
     * The maps already processed.
     */

    std::map<CompressedMap, int> maps;


    /**
     * The text for the duplicate levels.
     */

    QString m_text;


    /**
     * The number of steps needed.
     */

    int m_steps;
};


#endif
