/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_EXPORT_SOLUTIONS_DIALOG_INC_GUARD_H
#define EASYSOK_EXPORT_SOLUTIONS_DIALOG_INC_GUARD_H


#include <qstring.h>

#include <kdialogbase.h>


class KConfig;
class KLineEdit;
class QRadioButton;




/**
 * This class lets the user select, which solutions he wants to export.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ExportSolutionsDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Opens a dialog to export solutions.
     *
     * @param export_current_level If true, we can also export the current levels solution.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    ExportSolutionsDialog(bool export_current_level, QWidget * parent = 0, char const * name = 0);


    /**
     * Stores the selections.
     */

    virtual ~ExportSolutionsDialog();


    /**
     * Returns true, if we export only the solution of the current level.
     */

    bool exportCurrentLevel() const;


    /**
     * Returns true, if we export the solutions of the current collection.
     */

    bool exportCollection() const;


    /**
     * Returns true, if we export only the best solutions.
     */

    bool exportOnlyBest() const;


    /**
     * Returns true, if we export all solutions of a level.
     */

    bool exportAll() const;


    /**
     * Returns true, if we export only the solutions which match the regexp.
     */

    bool exportRegexpMatches() const;


    /**
     * Returns the solution regexp.
     */

    QString solutionRegexp() const;


public slots:

    /**
     * Shows the regexp editor if available.
     */

    void showRegExpEditor();


private slots:

    /**
     * Called when the export by regexp button is toggled.
     *
     * @param state The new state of the export by regexp button.
     */

    void regexpButtonToggled(bool state);


private:

    /**
     * Export only solutions of a level.
     */

    QRadioButton * m_export_level;


    /**
     * Export only solutions of a collection.
     */

    QRadioButton * m_export_collection;


    /**
     * Export solutions from all collections.
     */

    QRadioButton * m_export_all;


    /**
     * Export only the best solution per level.
     */
    QRadioButton * m_export_best;


    /**
     * Export all solutions of the levels.
     */

    QRadioButton * m_export_all_solutions;


    /**
     * Export solutions by name.
     */

    QRadioButton * m_export_solutions_by_name;


    /**
     * The regexp to export solutions by name.
     */

    KLineEdit * m_solutions_regexp;
};


#endif
