/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "highscore_dialog.h"

#include <qlistview.h>
#include <qstring.h>
#include <qvbox.h>

#include <kglobal.h>
#include <klistview.h>
#include <klocale.h>

#include "collection.h"
#include "collection_holder.h"
#include "compressed_map.h"
#include "solution_holder.h"




HighscoreDialog::HighscoreDialog(int collection_nr, QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, CollectionHolder::collection(collection_nr)->name(),
                Close | Help, Close, true),
    m_selected_level(0)
{
    m_list_view = new KListView(makeVBoxMainWidget());
    m_list_view->setShowSortIndicator(true);

    connect(m_list_view, SIGNAL(executed (QListViewItem *)), this, SLOT(levelSelected(QListViewItem *)));

    m_list_view->addColumn(i18n("Nr."));
    m_list_view->setColumnAlignment(0, AlignRight);
    m_list_view->addColumn(i18n("When solved"));
    m_list_view->setColumnAlignment(1, AlignLeft);
    m_list_view->addColumn(i18n("Pushes"));
    m_list_view->setColumnAlignment(2, AlignRight);
    m_list_view->addColumn(i18n("Linear pushes"));
    m_list_view->setColumnAlignment(3, AlignRight);
    m_list_view->addColumn(i18n("Gem changes"));
    m_list_view->setColumnAlignment(4, AlignRight);
    m_list_view->addColumn(i18n("Moves"));
    m_list_view->setColumnAlignment(5, AlignRight);

    Collection * collection = CollectionHolder::collection(collection_nr);
    int const number_of_levels = collection->numberOfLevels();

    for (int i = 0; i < number_of_levels; ++i)
    {
        QString number = QString::number(i + 1).rightJustify(3, '0', true) + "  ";
        CompressedMap const & map = collection->level(i).compressedMap();
        QListViewItem * item;

        if (SolutionHolder::hasSolution(map))
        {
            QDateTime const date_time = SolutionHolder::dateOfSolution(map, 0);
            int const pushes = SolutionHolder::pushesInSolution(map, 0);
            int const linear_pushes = SolutionHolder::linearPushesInSolution(map, 0);
            int const gem_changes = SolutionHolder::gemChangesInSolution(map, 0);
            int const moves = SolutionHolder::movesInSolution(map, 0);
            QString date = KGlobal::locale()->formatDateTime(date_time, true);
            item = new QListViewItem(m_list_view, number, date, QString::number(pushes),
                                     QString::number(linear_pushes), QString::number(gem_changes),
                                     QString::number(moves));
        }
        else
        {
            item = new QListViewItem(m_list_view, number, i18n("Not solved yet"));
        }

        m_list_view->insertItem(item);
    }

    setHelp("highscore-dialog");
}



int HighscoreDialog::selectedLevel() const
{
    return m_selected_level;
}


void HighscoreDialog::levelSelected(QListViewItem * item)
{
    m_selected_level = item->text(0).toInt() - 1;
    accept();
}
