/*
 *   EasySok --- A(noter) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_HIGHSCORE_DIALOG_INC_GUARD_H
#define EASYSOK_HIGHSCORE_DIALOG_INC_GUARD_H


#include <kdialogbase.h>


class KListView;
class QListViewItem;




/**
 * Shows the highscores of a collection and lets the user select a level.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class HighscoreDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Constructs the object.
     *
     * @param collection_nr The index of the collection to display.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    HighscoreDialog(int collection_nr, QWidget * parent = 0, char const * name = 0);



    /**
     * Returns the level selected by the user.
     */

    int selectedLevel() const;


public slots:

    /**
     * Called when the user selected a level.
     *
     * @parent item The item selected.
     */

    void levelSelected(QListViewItem * item);


private:

    /**
     * The list view with the level data.
     */

    KListView * m_list_view;


    /**
     * The selected level.
     */

    int m_selected_level;
};



#endif
