/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "image_effect.h"

#include <cassert>

#include <qimage.h>




// Copied mostly from KImageEffect::blendOnLower()

void ImageEffect::blendOnLower(int x_offset, int y_offset, QImage const & upper, QImage & lower)
{
    assert(upper.width() > 0);
    assert(upper.height() > 0);
    assert(upper.depth() == 32);
    assert(lower.depth() == 32);

    int const upper_width = upper.width();
    int const upper_height = upper.height();
    int const lower_width = lower.width();
    int const lower_height = lower.height();
    int width = upper_width;
    int height = upper_height;
    int upper_x_offset = 0;
    int upper_y_offset = 0;
    int alpha;

    if ( (x_offset + width > lower_width) || (y_offset + height > lower_height) ||
         (x_offset < 0) || (y_offset < 0) )
    {
        if ( (x_offset > lower_width) || (y_offset > lower_height) )
        {
            return;
        }

        if (x_offset < 0)
        {
            upper_x_offset = -x_offset;
            width += x_offset;
            x_offset = 0;
        }

        if (width + x_offset > lower_width)
        {
            width = lower_width - x_offset;
        }

        if (y_offset < 0)
        {
            upper_y_offset = -y_offset;
            height += y_offset;
            y_offset = 0;
        }

        if (height + y_offset > lower_height)
        {
            height = lower_height - y_offset;
        }

        if ( (upper_x_offset > upper_width) || (upper_y_offset >= upper_height) )
        {
            return;
        }

        if ( (width <= 0) || (height <= 0) )
        {
            return;
        }
    }

    for (int y = 0; y < height; ++y)
    {
        uchar * upper_line = upper.scanLine(y + upper_y_offset) + ((width + upper_x_offset) << 2) - 1;
        uchar * lower_line = lower.scanLine(y + y_offset) + ((width + x_offset) << 2) - 1;

        int x = width - 1;

        do
        {
            while ( !(alpha = *upper_line) && (x > 0) )
            {
                upper_line -= 4;
                lower_line -= 4;
                --x;
            }

            *lower_line = 255 - (((255 - *upper_line) * (255 - *lower_line) + 255) >> 8);
            --upper_line;
            --lower_line;
            *lower_line += ( ((*upper_line - *lower_line) * alpha) >> 8);
            --upper_line;
            --lower_line;
            *lower_line += ( ((*upper_line - *lower_line) * alpha) >> 8);
            --upper_line;
            --lower_line;
            *lower_line += ( ((*upper_line - *lower_line) * alpha) >> 8);
            --upper_line;
            --lower_line;
            --x;
        } while (x >= 0);
    }
}

void ImageEffect::blend(QImage & image, float val, QRgb color, bool fade_rgb, bool fade_alpha)
{
    blend(image, static_cast<int> (val * 256), color, fade_rgb, fade_alpha);
}


void ImageEffect::blend(QImage & image, int val, QRgb color, bool fade_rgb, bool fade_alpha)
{
    assert(image.width() > 0);
    assert(image.height() > 0);
    assert(image.depth() == 32);

    int const to_fac = val;
    int from_fac = 256 - to_fac;
    int const to_red = qRed(color) * to_fac;
    int const to_green = qGreen(color) * to_fac;
    int const to_blue = qBlue(color) * to_fac;
    int const to_alpha = qAlpha(color) * to_fac;
    int const width = image.width();
    int const height = image.height();

    if (fade_alpha)
    {
        if (fade_rgb)
        {
            for (int y = 0; y < height; ++y)
            {
                QRgb * scanline = reinterpret_cast<QRgb *> (image.scanLine(y));

                for (int x = 0; x < width; ++x)
                {
                    QRgb from_color = *scanline;
                    *scanline = qRgba((qRed(from_color) * from_fac + to_red) >> 8,
                                      (qGreen(from_color) * from_fac + to_green) >> 8,
                                      (qBlue(from_color) * from_fac + to_blue) >> 8,
                                      (qAlpha(from_color) * from_fac + to_alpha) >> 8);
                    ++scanline;
                }
            }
        }
        else
        {
            for (int y = 0; y < height; ++y)
            {
                QRgb * scanline = reinterpret_cast<QRgb *> (image.scanLine(y));

                for (int x = 0; x < width; ++x)
                {
                    QRgb from_color = *scanline;
                    int const from_alpha = qAlpha(from_color);
                    *scanline = qRgba(qRed(from_color), qGreen(from_color), qBlue(from_color),
                                      ((from_alpha * from_fac + to_alpha) * from_alpha) >> 16);
                    ++scanline;
                }
            }
        }
    }
    else
    {
        for (int y = 0; y < height; ++y)
        {
            QRgb * scanline = reinterpret_cast<QRgb *> (image.scanLine(y));

            for (int x = 0; x < width; ++x)
            {
                QRgb from_color = *scanline;
                *scanline = qRgba((qRed(from_color) * from_fac + to_red) >> 8,
                                  (qGreen(from_color) * from_fac + to_green) >> 8,
                                  (qBlue(from_color) * from_fac + to_blue) >> 8,
                                  qAlpha(from_color));
                ++scanline;
            }
        }
    }
}


void ImageEffect::colorize(QImage & image, float val, QRgb color)
{
    colorize(image, static_cast<int> (val * 256),color);
}


void ImageEffect::colorize(QImage & image, int val, QRgb color)
{
    assert(image.width() > 0);
    assert(image.height() > 0);
    assert(image.depth() == 32);

    int const to_fac = val;
    int from_fac = 256 - to_fac;
    int const to_red = qRed(color);
    int const to_green = qGreen(color);
    int const to_blue = qBlue(color);
    int const width = image.width();
    int const height = image.height();

    for (int y = 0; y < height; ++y)
    {
        QRgb * scanline = reinterpret_cast<QRgb *> (image.scanLine(y));

        for (int x = 0; x < width; ++x)
        {
            QRgb const from_color = *scanline;
            int const brightness = (qRed(from_color) + qGreen(from_color) + qBlue(from_color)) / 3;
            *scanline = qRgba((qRed(from_color) * from_fac + to_red * to_fac) * brightness >> 16,
                              (qGreen(from_color) * from_fac + to_green * to_fac) * brightness >> 16,
                              (qBlue(from_color) * from_fac + to_blue * to_fac) * brightness >> 16,
                              qAlpha(from_color));
            ++scanline;
        }
    }
}


void ImageEffect::scale(QImage & src, int new_width, int new_height)
{
    int const old_width = src.width();
    int const old_height = src.height();

    if ( (old_width == new_width) && (old_height == new_height) )
    {
        return;
    }

    QImage dst(new_width, new_height, 32);

    bool const has_alpha = src.hasAlphaBuffer();

    if (has_alpha)
    {
        dst.setAlphaBuffer(true);
    }

    int const scale = 4096;

    static int last_old_width = -1;
    static int last_old_height = -1;
    static int last_new_width = -1;
    static int last_new_height = -1;

    static std::vector<int> col_lengths;
    static std::vector<int> col_starts;
    static std::vector<int> col_factor_offsets;
    static std::vector<Q_UINT32> col_factors;

    static std::vector<int> row_lengths;
    static std::vector<int> row_starts;
    static std::vector<int> row_factor_offsets;
    static std::vector<Q_UINT32> row_factors;

    if ( (last_old_height != old_height) || (last_new_height != new_height) )
    {
        calcScaleFactors(old_height, new_height, scale, row_lengths,
                         row_starts, row_factor_offsets, row_factors);

        last_old_height = old_height;
        last_new_height = new_height;
    }

    if ( (last_old_width != old_width) || (last_new_width != new_width) )
    {
        calcScaleFactors(old_width, new_width, scale, col_lengths,
                         col_starts, col_factor_offsets, col_factors);

        last_old_width = old_width;
        last_new_width = new_width;
    }

    if (has_alpha)
    {
        std::vector<Q_UINT32> temp_red(old_width);
        std::vector<Q_UINT32> temp_green(old_width);
        std::vector<Q_UINT32> temp_blue(old_width);
        std::vector<Q_UINT32> temp_alpha(old_width);

        for (int y = 0; y < new_height; ++y)
        {
            for (int x = 0; x < old_width; ++x)
            {
                temp_red[x] = 0;
                temp_green[x] = 0;
                temp_blue[x] = 0;
                temp_alpha[x] = 0;
            }

            int const from_y2 = row_starts[y];
            int const to_y2 = from_y2 + row_lengths[y];
            int row_factor_offset = row_factor_offsets[y];

            for (int y2 = from_y2; y2 < to_y2; ++y2)
            {
                QRgb const * scanline = reinterpret_cast<QRgb const *> (src.scanLine(y2));

                Q_UINT32 const factor = row_factors[row_factor_offset];
                ++row_factor_offset;

                for (int x = 0; x < old_width; ++x)
                {
                    QRgb const pixel = scanline[x];
                    Q_UINT32 const act_alpha = qAlpha(pixel);

                    if (act_alpha)
                    {
                        Q_UINT32 const alpha_factor = act_alpha * factor;

                        temp_red[x] += (qRed(pixel) * alpha_factor) >> 8;
                        temp_green[x] += (qGreen(pixel) * alpha_factor) >> 8;
                        temp_blue[x] += (qBlue(pixel) * alpha_factor) >> 8;
                        temp_alpha[x] += alpha_factor;
                    }
                }
            }

            QRgb * scanline = reinterpret_cast<QRgb *> (dst.scanLine(y));

            for (int x = 0; x < new_width; ++x)
            {
                int const from_x2 = col_starts[x];
                int const to_x2 = from_x2 + col_lengths[x];
                int col_factor_offset = col_factor_offsets[x];

                Q_UINT32 red = 0;
                Q_UINT32 green = 0;
                Q_UINT32 blue = 0;
                Q_UINT32 alpha = 0;

                for (int x2 = from_x2; x2 < to_x2; ++x2)
                {
                    Q_UINT32 const factor = col_factors[col_factor_offset];
                    ++col_factor_offset;

                    Q_UINT32 const act_alpha = temp_alpha[x2];

                    if (act_alpha)
                    {
                        red += temp_red[x2] * factor;
                        green += temp_green[x2] * factor;
                        blue += temp_blue[x2] * factor;
                        alpha += act_alpha * factor;
                    }
                }

                alpha >>= 8;

                if (alpha)
                {
                    scanline[x] = qRgba(red / alpha, green / alpha, blue / alpha, alpha >> 16);
                }
                else
                {
                    scanline[x] = qRgba(255, 255, 255, 0);
                }
            }
        }
    }
    else
    {
        std::vector<Q_UINT32> temp_red(old_width);
        std::vector<Q_UINT32> temp_green(old_width);
        std::vector<Q_UINT32> temp_blue(old_width);

        for (int y = 0; y < new_height; ++y)
        {
            int const from_y2 = row_starts[y];
            int const to_y2 = from_y2 + row_lengths[y];
            int row_factor_offset = row_factor_offsets[y];

            for (int x = 0; x < old_width; ++x)
            {
                temp_red[x] = 0;
                temp_green[x] = 0;
                temp_blue[x] = 0;
            }

            for (int y2 = from_y2; y2 < to_y2; ++y2)
            {
                QRgb const * scanline = reinterpret_cast<QRgb *> (src.scanLine(y2));

                Q_UINT32 const factor = row_factors[row_factor_offset];
                ++row_factor_offset;

                for (int x = 0; x < old_width; ++x)
                {
                    QRgb const pixel = scanline[x];

                    temp_red[x] += qRed(pixel) * factor;
                    temp_green[x] += qGreen(pixel) * factor;
                    temp_blue[x] += qBlue(pixel) * factor;
                }
            }

            QRgb * scanline = reinterpret_cast<QRgb *> (dst.scanLine(y));

            for (int x = 0; x < new_width; ++x)
            {
                int const from_x2 = col_starts[x];
                int const to_x2 = from_x2 + col_lengths[x];
                int col_factor_offset = col_factor_offsets[x];

                Q_UINT32 red = 0;
                Q_UINT32 green = 0;
                Q_UINT32 blue = 0;

                for (int x2 = from_x2; x2 < to_x2; ++x2)
                {
                    Q_UINT32 const factor = col_factors[col_factor_offset];
                    ++col_factor_offset;

                    red += temp_red[x2] * factor;
                    green += temp_green[x2] * factor;
                    blue += temp_blue[x2] * factor;
                }

                scanline[x] = qRgb(red >> 24, green >> 24, blue >> 24);
            }
        }
    }

    src = dst;
}


void ImageEffect::calcScaleFactors(int from_pixels, int to_pixels, int sum, std::vector<int> & lengths,
                                   std::vector<int> & starts, std::vector<int> & factor_offsets,
                                   std::vector<Q_UINT32> & factors)
{
    int const div = from_pixels / to_pixels;
    int const rem = from_pixels - div * to_pixels;
    int const sum_sum = rem + div * to_pixels;
    int const sum_div = sum / sum_sum;
    int const sum_rem = sum - sum_div * sum_sum;
    int part_div = 0;
    int part_rem = 0;

    lengths.resize(to_pixels);
    starts.resize(to_pixels);
    factor_offsets.resize(to_pixels);
    factors.resize(0);

    for (int i = 0; i < to_pixels; ++i)
    {
        int const from_index = part_div;
        int const from_rem = part_rem;

        part_rem += rem;

        if (part_rem >= to_pixels)
        {
            part_rem -= to_pixels;
            ++part_div;
        }

        part_div += div;

        int to_index = part_div;
        int to_rem = part_rem - 1;

        if (to_rem < 0)
        {
            to_rem = to_pixels - 1;
            --to_index;
        }

        int const length = to_index - from_index + 1;

        lengths[i] = length;
        starts[i] = from_index;
        factor_offsets[i] = static_cast<int> (factors.size());

        if (length == 1)
        {
            factors.push_back(sum);
        }
        else
        {
            int sum_part_div = 0;
            int sum_part_rem = 0;

            for (int j = 0; j < length; ++j)
            {
                int act_rem = to_pixels;

                if (j == 0)
                {
                    act_rem = to_pixels - from_rem;
                }
                else if (j == length - 1)
                {
                    act_rem = to_rem + 1;
                }

                int new_sum_part_rem = sum_part_rem + act_rem * sum_rem;
                int const new_sum_part_rem_div = new_sum_part_rem / sum_sum;
                new_sum_part_rem -= new_sum_part_rem_div * sum_sum;
                int const new_sum_part_div = sum_part_div + act_rem * sum_div + new_sum_part_rem_div;

                factors.push_back(new_sum_part_div - sum_part_div);

                sum_part_div = new_sum_part_div;
                sum_part_rem = new_sum_part_rem;
            }
        }
    }
}
