/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_IMAGE_STORER_INC_GUARD_H
#define EASYSOK_IMAGE_STORER_INC_GUARD_H


#include <qimage.h>


class Map;
class QIODevice;
class Theme;




/**
 * Stores a map as an image file.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ImageStorer
{
public:

    /**
     * Stores the given map as an image.
     *
     * @param device The device to use.
     * @param format The format to use.
     * @param map The map to display.
     * @param piece_size The size of a field (width and height).
     * @param theme The theme to use.
     * @param direction The direction of the keeper.
     * @param use_background If true, we use the background of the theme.
     * @param low_quality If true, we use only low quality.
     * @return True, if everything went fine or an error code otherwise.
     */

    static bool store(QIODevice * device, char const * format, Map const & map, int piece_size,
                      Theme const & theme, int direction, bool use_background, bool low_quality);


    /**
     * The same as store(), only that the image itself is returned.
     */

    static QImage createImage(Map const & map, int piece_size, Theme const & theme,
                              int direction, bool use_background, bool low_quality);
};


#endif
