/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "image_storer_dialog.h"

#include <algorithm>

#include <qcheckbox.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <klocale.h>
#include <knuminput.h>

#include "map.h"
#include "theme.h"




ImageStorerDialog::ImageStorerDialog(Map const & map, Theme const * theme,
                                     QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Image setup"), Ok | Help | Cancel, Ok, true),
    m_theme(theme),
    m_map_width(map.width()),
    m_map_height(map.height())
{
    QVBox * page = makeVBoxMainWidget();

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    QString const box1_text = i18n("Set the size of the image");
    QGroupBox * box1 = new QGroupBox(2, Vertical, box1_text, page);

    int piece_size = config->readNumEntry("Image piece size", 32);
    piece_size = std::min(std::max(piece_size, 4), 256);
    m_piece_size = new KIntNumInput(piece_size, box1);
    m_piece_size->setRange(4, 256);
    m_piece_size->setSuffix(" " + i18n("pixel"));
    m_piece_size->setLabel(i18n("Size of a field"));
    connect(m_piece_size, SIGNAL(valueChanged(int)), this, SLOT(pieceSizeChanged(int)));

    m_whole_size = new QLabel(box1);
    pieceSizeChanged(m_piece_size->value());

    QString const box2_text = i18n("Make background transparent");
    QGroupBox * box2 = new QGroupBox(1, Vertical, box2_text, page);

    m_transparent_background = new QCheckBox(i18n("Make background transparent"), box2);
    m_transparent_background->setChecked(config->readNumEntry("Image transparent background", true));

    QString const box3_text = i18n("Set quality of the image");
    QGroupBox * box3 = new QGroupBox(3, Vertical, box3_text, page);

    m_low_quality = new QCheckBox(i18n("Use low quality images"), box3);
    m_low_quality->setChecked(config->readNumEntry("Image low quality images", false));

    setHelp("image-storer-dialog", QString::null);
}



ImageStorerDialog::~ImageStorerDialog()
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    config->writeEntry("Image piece size", m_piece_size->value());
    config->writeEntry("Image transparent background", m_transparent_background->isChecked());
    config->writeEntry("Image low quality images", m_low_quality->isChecked());
}


bool ImageStorerDialog::transparentBackground() const
{
    return m_transparent_background->isChecked();
}


int ImageStorerDialog::pieceSize() const
{
    return m_piece_size->value();
}


bool ImageStorerDialog::lowQuality() const
{
    return m_low_quality->isChecked();
}


void ImageStorerDialog::pieceSizeChanged(int size)
{
    int const width = m_map_width * size + static_cast<int> (m_theme->leftBorder() * size) +
                      static_cast<int> (m_theme->rightBorder() * size);
    int const height = m_map_height * size + static_cast<int> (m_theme->upperBorder() * size) +
                       static_cast<int> (m_theme->lowerBorder() * size);

    m_whole_size->setText(i18n("The whole size will be %1x%2.").arg(width).arg(height));
}
