/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_IMAGE_STORER_DIALOG_INC_GUARD_H
#define EASYSOK_IMAGE_STORER_DIALOG_INC_GUARD_H


#include <kdialogbase.h>


class KIntNumInput;
class Map;
class QCheckBox;
class QLabel;
class Theme;




/**
 * The configuration dialog for exporting a game as an image.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ImageStorerDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Constructs the object.
     *
     * @param map The map to use.
     * @param theme The theme to use.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    ImageStorerDialog(Map const & map, Theme const * theme, QWidget * parent = 0, char const * name = 0);


    /**
     * Stores the values.
     */

    virtual ~ImageStorerDialog();


    /**
     * Returns true, if the background should be transparent.
     */

    bool transparentBackground() const;


    /**
     * Returns the piece size.
     */

    int pieceSize() const;


    /**
     * Return true, if we only use low quality images.
     */

    bool lowQuality() const;


private slots:

    /**
     * Called, when the piece size has changed.
     *
     * @param size The new piece size.
     */

    void pieceSizeChanged(int size);


private:

    /**
     * The theme to use.
     */

    Theme const * m_theme;


    /**
     * The background checkbox.
     */

    QCheckBox * m_transparent_background;


    /**
     * The piece size.
     */

    KIntNumInput * m_piece_size;


    /**
     * Label which displays the whole image size.
     */

    QLabel * m_whole_size;


    /**
     * Use low quality images.
     */

    QCheckBox * m_low_quality;


    /**
     * The map width.
     */

    int m_map_width;


    /**
     * The map height.
     */

    int m_map_height;
};


#endif
