/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "import_solutions_dialog.h"

#include <qbuttongroup.h>
#include <qlabel.h>
#include <qradiobutton.h>
#include <qstring.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <klineedit.h>
#include <klocale.h>




ImportSolutionsDialog::ImportSolutionsDialog(QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Import solutions"), Ok | Cancel | Help)
{
    QVBox * page = makeVBoxMainWidget();

    QString const group1_text = i18n("Solutions for which levels to import");
    QButtonGroup * group1 = new QButtonGroup(3, Vertical, group1_text, page);
    group1->setRadioButtonExclusive(true);

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    int const options1  = config->readNumEntry("Import solutions options 1", 2);

    m_import_current_solution = new QRadioButton(i18n("Import solution for current level"), group1);
    m_import_current_solution->setChecked(options1 == 2);

    QString const col_sol_text = i18n("Import solutions for current collection");
    m_import_collection_solutions = new QRadioButton(col_sol_text, group1);
    m_import_collection_solutions->setChecked(options1 == 1);

    m_import_all_solutions = new QRadioButton(i18n("Import solutions of all collections"), group1);
    m_import_all_solutions->setChecked(options1 == 0);

    QString const group2_text = i18n("What kind of solutions to import");
    QButtonGroup * group2 = new QButtonGroup(4, Vertical, group2_text, page);
    group2->setRadioButtonExclusive(true);

    int const options2 = config->readNumEntry("Import solutions options 2", 3);

    m_import_better_solutions = new QRadioButton(i18n("Import only better solutions"), group2);
    m_import_better_solutions->setChecked(options2 == 0);

    m_import_best_solution = new QRadioButton(i18n("Import only best solution for a level"), group2);
    m_import_best_solution->setChecked(options2 == 1);

    QString const better_best_text = i18n("Import only the best solution, better than current.");
    m_import_better_best_solutions = new QRadioButton(better_best_text, group2);
    m_import_better_best_solutions->setChecked(options2 == 2);

    m_ignore_solution_quality = new QRadioButton(i18n("Import all solutions"), group2);
    m_ignore_solution_quality->setChecked(options2 == 3);


    QString const group3_text = i18n("Solution optimization");
    QButtonGroup * group3 = new QButtonGroup(3, Vertical, group3_text, page);
    group3->setRadioButtonExclusive(true);

    int const options3 = config->readNumEntry("Import solutions options 3", 2);

    m_optimize_pushes = new QRadioButton(i18n("Optimize pushes and moves in imported solutions"), group3);
    m_optimize_pushes->setChecked(options3 == 0);

    m_optimize_moves = new QRadioButton(i18n("Optimize moves in imported solutions"), group3);
    m_optimize_moves->setChecked(options3 == 1);

    m_optimize_none = new QRadioButton(i18n("Don't optimize solutions"), group3);
    m_optimize_none->setChecked(options3 == 2);

    new QLabel(i18n("Text to append to annotations in imported solutions"), page);
    m_append_annotation = new KLineEdit(config->readEntry("Import solutions append line", ""), page);

    setHelp("import-solutions-dialog");
}


ImportSolutionsDialog::~ImportSolutionsDialog()
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    int options1 = 2;

    if (m_import_all_solutions->isChecked())
    {
        options1 = 0;
    }
    else if (m_import_collection_solutions->isChecked())
    {
        options1 = 1;
    }

    config->writeEntry("Import solutions options 1", options1);

    int options2 = 3;

    if  (m_import_better_solutions->isChecked())
    {
        options2 = 0;
    }
    else if (m_import_best_solution->isChecked())
    {
        options2 = 1;
    }
    else if (m_import_better_best_solutions->isChecked())
    {
        options2 = 2;
    }

    config->writeEntry("Import solutions options 2", options2);

    int options3 = 2;

    if (m_optimize_pushes->isChecked())
    {
        options3 = 0;
    }
    else if (m_optimize_moves->isChecked())
    {
        options3 = 1;
    }

    config->writeEntry("Import solutions options 3", options3);

    config->writeEntry("Import solutions append line", m_append_annotation->text());
}


bool ImportSolutionsDialog::importSolutionForCurrentLevel() const
{
    return m_import_current_solution->isChecked();
}


bool ImportSolutionsDialog::importSolutionsForCurrentCollection() const
{
    return m_import_collection_solutions->isChecked();
}


bool ImportSolutionsDialog::importOnlyBetterSolutions() const
{
    return m_import_better_solutions->isChecked();
}


bool ImportSolutionsDialog::importOnlyBestSolution() const
{
    return m_import_best_solution->isChecked();
}


bool ImportSolutionsDialog::importOnlyBestBetterSolution() const
{
    return m_import_better_best_solutions->isChecked();
}


bool ImportSolutionsDialog::optimizePushes() const
{
    return m_optimize_pushes->isChecked();
}


bool ImportSolutionsDialog::optimizeMoves() const
{
    return m_optimize_moves->isChecked();
}


QString ImportSolutionsDialog::appendAnnotation() const
{
    return m_append_annotation->text();
}
