/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_IMPORT_SOLUTIONS_DIALOG_INC_GUARD_H
#define EASYSOK_IMPORT_SOLUTIONS_DIALOG_INC_GUARD_H


#include <kdialogbase.h>

#include <qstring.h>


class KLineEdit;
class QRadioButton;




/**
 * Dialog to select options for importng solutions.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ImportSolutionsDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Creates the dialog.
     *
     * @param parent The parent widget.
     * @param name The internal name of the widget.
     */

    ImportSolutionsDialog(QWidget * parent = 0, char const * name = 0);


    /**
     * Stores the selections.
     */

    virtual ~ImportSolutionsDialog();


    /**
     * Returns true, if we should only import a solution for the current level.
     */

    bool importSolutionForCurrentLevel() const;


    /**
     * Returns true, if we should only import solutions for the current collection.
     */

    bool importSolutionsForCurrentCollection() const;


    /**
     * Returns true, if we only import better solutions.
     */

    bool importOnlyBetterSolutions() const;


    /**
     * Returns true, if we import only the best solution.
     */

    bool importOnlyBestSolution() const;


    /**
     * Returns true, if we import only the best better solution.
     */

    bool importOnlyBestBetterSolution() const;


    /**
     * Returns true, if we should optimized the pushes and moves of the solutions.
     */

    bool optimizePushes() const;


    /**
     * Returns true, if we should optimized the moves of the solutions.
     */

    bool optimizeMoves() const;


    /**
     * Returns the text to append to each imported solutions annotation.
     */

    QString appendAnnotation() const;


private:

    /**
     * If set, we import only the solution of the current level.
     */

    QRadioButton * m_import_current_solution;


    /**
     * If set, we import only the solutions of the current collection.
     */

    QRadioButton * m_import_collection_solutions;


    /**
     * If set, we import all solutions.
     */

    QRadioButton * m_import_all_solutions;


    /**
     * If set, we import only better solutions.
     */

    QRadioButton * m_import_better_solutions;


    /**
     * If set, we import only the best solution.
     */

    QRadioButton * m_import_best_solution;


    /**
     * If set, we import only the best solution, if it is better than the currently best solution.
     */

    QRadioButton * m_import_better_best_solutions;


    /**
     * If set, we don't care you good a solutions is.
     */

    QRadioButton * m_ignore_solution_quality;


    /**
     * If set, we should optimize pushes and moves.
     */

    QRadioButton * m_optimize_pushes;


    /**
     * If set, we should optimize pushes.
     */

    QRadioButton * m_optimize_moves;


    /**
     * If set, we dont optimize.
     */

    QRadioButton * m_optimize_none;


    /**
     * The annotation to append to all solutions.
     */

    KLineEdit * m_append_annotation;
};


#endif
