/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "import_user_dialog.h"

#include <qlabel.h>
#include <qstringlist.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <klineedit.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <krestrictedline.h>
#include <kurl.h>

#include "proxy_suggestor.h"
#include "query_dialog.h"




ImportUserDialog::ImportUserDialog(QWidget * parent, char const * name) :
    AdvancedOptionsDialog(parent, name, true, i18n("Import User"), Ok | Cancel | Help, Ok, true)
{
    QVBox * page = makeVBoxMainWidget();

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    new QLabel(i18n("The nickname of the user to import"), page);
    m_nickname = new KRestrictedLine(page, 0,
                                     "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-");

    new QLabel(i18n("The users password"), page);
    m_passwd = new KLineEdit(page);
    m_passwd->setEchoMode(QLineEdit::Password);

    createAdvancedOptionsButton(page);

    addAdvancedWidget(new QLabel(i18n("The server to use"), page));

    QString server = config->readEntry("Highscore server", "http://easysok.sourceforge.net/highscores");
    m_server = new KLineEdit(server, page);
    addAdvancedWidget(m_server);

    addAdvancedWidget(new QLabel(i18n("The proxy to use (empty if not needed)"), page));

    QString proxy;
    int proxy_port;

    if (config->hasKey("Proxy server"))
    {
        proxy = config->readEntry("Proxy server", "");
        proxy_port = config->readNumEntry("Proxy port", 8080);
    }
    else
    {
        ProxySuggestor::suggestProxy(proxy, proxy_port);
    }

    m_proxy = new KLineEdit(proxy, page);
    addAdvancedWidget(m_proxy);

    addAdvancedWidget(new QLabel(i18n("The port of the proxy"), page));

    m_proxy_port = new KRestrictedLine(page, 0, "0123456789");
    m_proxy_port->setText(QString::number(proxy_port));
    addAdvancedWidget(m_proxy_port);

    setHelp("import-user-dialog");
}


void ImportUserDialog::slotOk()
{
    if (m_nickname->text().isEmpty())
    {
        KMessageBox::error(this, i18n("You haven't specified a nickname!"));
    }
    else
    {
        KConfig * config = KApplication::kApplication()->config();
        config->setGroup("");

        config->writeEntry("Highscore server", m_server->text());
        config->sync();

        QString query = "nickname=" + KURL::encode_string(m_nickname->text());
        query += "&passwd=" + KURL::encode_string(m_passwd->text());

        QueryDialog dialog(i18n("Importing User"), i18n("Trying to import the specified user ..."),
                           KURL(m_server->text()), m_proxy->text(), m_proxy_port->text().toInt(),
                           "export_user.php", query, this);

        if (!dialog.exec() || (dialog.result() != ServerConnector::OK))
        {
            KMessageBox::error(this, dialog.resultText());
        }
        else
        {
            QStringList data = QStringList::split('\n', dialog.data(), true);

            if (data.count() < 2)
            {
                KMessageBox::error(this, i18n("Could not get user data!"));
            }
            else
            {
                config->setGroup("UserGroup-" + m_nickname->text());
                config->writeEntry("Name", data[0]);
                config->writeEntry("Email", data[1]);
                config->writeEntry("Password", m_passwd->text());
                config->writeEntry("Server", m_server->text());
                config->writeEntry("Proxy", m_proxy->text());
                config->writeEntry("Proxy port", m_proxy_port->text().toInt());

                config->setGroup("");
                QStringList nicknames = config->readListEntry("Nicknames");
                nicknames.remove(m_nickname->text());
                nicknames.append(m_nickname->text());
                config->writeEntry("Nicknames", nicknames);

                config->writeEntry("Current user", m_nickname->text());

                config->sync();

                KDialogBase::slotOk();
                KMessageBox::information(this, i18n("The user has been imported!"));
            }
        }
    }
}
