/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_INFO_DIALOG_INC_GUARD_H
#define EASYSOK_INFO_DIALOG_INC_GUARD_H


#include <vector>

#include <kdialogbase.h>


class Collection;
class KURLLabel;
class Level;
class QLabel;




/**
 * Displays information about a level or collection.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class InfoDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Creates the dialog.
     *
     * @param level The level for which to display informations.
     * @param temporary If true the level is in a temporary collection.
     * @param parent The parent of the widget.
     * @param name The internal name of the widget.
     */

    InfoDialog(Level const & level, bool temporary, QWidget * parent = 0, char const * name = 0);


    /**
     * Creates the dialog.
     *
     * @param collection The collection for which to display informations.
     * @param temporary If true the collection is temporary.
     * @param parent The parent of the widget.
     * @param name The internal name of the widget.
     */

    InfoDialog(Collection const & collection, bool temporary, QWidget * parent = 0, char const * name = 0);


private slots:

    /**
     * Called, when the user clicked a author email address.
     *
     * @param url The url to use.
     */

    void emailClicked(const QString & url);


    /**
     * Called, when the user clicked the homepage.
     *
     * @param url The url to use.
     */

    void homepageClicked(const QString & url);


private:

    /**
     * Sets up the dialog.
     *
     * @param author The authors.
     * @param emails The email addresses of the authors.
     * @param homepage The homepage of the level/collection.
     * @param copyright The copyright of the level.
     * @param name The name of the level/collection.
     * @param info Additional information.
     * @param difficulty The difficulty.
     * @param temporary May contain a string which marks the level/collection as temporary.
     */

    void setupDialog(QStringList const & authors, QStringList const & emails, QString const & homepage,
                     QString const & copyright, QString const & name, QString const & info,
                     int difficulty, QString const & temporary);
};


#endif
