/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "level_properties_dialog.h"

#include <qcombobox.h>
#include <qframe.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qmultilineedit.h>

#include <kdialog.h>
#include <klineedit.h>
#include <klocale.h>

#include "difficulty.h"
#include "level.h"




LevelPropertiesDialog::LevelPropertiesDialog(Level const & level, QWidget * parent, const char * name) :
    KDialogBase(parent, name, true, i18n("Level Properies"), Ok | Help | Cancel, Ok, true)
{
    QFrame * page =  makeMainWidget();
    QVBoxLayout * layout = new QVBoxLayout(page);
    QLabel * label;

    label = new QLabel(i18n("Author(s):"), page);
    layout->addWidget(label);
    m_author = new KLineEdit(level.authorEmailLine(), page);
    layout->addWidget(m_author);
    layout->addSpacing(KDialog::spacingHint());

    label = new QLabel(i18n("Homepage:"), page);
    layout->addWidget(label);

    m_hompage = new KLineEdit(level.homepage(), page);
    layout->addWidget(m_hompage);
    layout->addSpacing(KDialog::spacingHint());

    label = new QLabel(i18n("Copyright:"), page);
    layout->addWidget(label);

    m_copyright = new KLineEdit(level.copyright(), page);
    layout->addWidget(m_copyright);
    layout->addSpacing(KDialog::spacingHint());

    label = new QLabel(i18n("Name:"), page);
    layout->addWidget(label);

    m_name = new KLineEdit(level.name(), page);
    layout->addWidget(m_name);
    layout->addSpacing(KDialog::spacingHint());

    label = new QLabel(i18n("Difficulty:"), page);
    layout->addWidget(label);
    m_difficulty = new QComboBox(false, page);

    for (int i = -1; i <= 10; ++i)
    {
        m_difficulty->insertItem(Difficulty::text(i));
    }

    m_difficulty->setCurrentItem(level.difficulty() + 1);
    layout->addWidget(m_difficulty);
    layout->addSpacing(KDialog::spacingHint());

    label = new QLabel(i18n("Info:"), page);
    layout->addWidget(label);

    m_info = new QMultiLineEdit(page);
    m_info->setText(level.info());
    layout->addWidget(m_info);
}


QString LevelPropertiesDialog::author() const
{
    return m_author->text();
}


QString LevelPropertiesDialog::homepage() const
{
    return m_hompage->text();
}


QString LevelPropertiesDialog::copyright() const
{
    return m_copyright->text();
}


QString LevelPropertiesDialog::name() const
{
    return m_name->text();
}


QString LevelPropertiesDialog::info() const
{
    return m_info->text();
}


int LevelPropertiesDialog::difficulty() const
{
    return m_difficulty->currentItem() - 1;
}
