/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <qdir.h>
#include <qfileinfo.h>

#include <kaboutdata.h>
#include <kapp.h>
#include <kcmdlineargs.h>
#include <kconfig.h>
#include <kglobal.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kstddirs.h>
#include <kuniqueapp.h>
#include <kwin.h>

#include "bookmarks.h"
#include "level.h"
#include "collection.h"
#include "collection_holder.h"
#include "create_user_dialog.h"
#include "main_window.h"
#include "solution_holder.h"
#include "theme_holder.h"




static KCmdLineOptions options[] =
{
    {0, 0, 0}
};


int main(int argc, char * argv[])
{
    QString exe_name = argv[0];

    KAboutData about("easysok",
                     "EasySok",
                     "0.3.5",
                     I18N_NOOP("A Sokoban game for KDE"),
                     KAboutData::License_GPL_V2,
		     I18N_NOOP("(C) 2001-2005 by Ralf Schmelter"),
		     0,
                     "http://easysok.sourceforge.net/",
                     "ralf.schmelter@t-online.de");
    about.addAuthor("Ralf Schmelter",0 , "ralf.schmelter@t-online.de",
                    "http://easysok.sourceforge.net/" );
    about.addCredit("Aymeric du Peloux",
                    I18N_NOOP("Provided the 'Minicosmos', 'Microcosmos', 'Nabokosmos'\n"
                              "and 'Picokosmos' collections."),
                    "aymeric.du-peloux@gadz.org",
                    "http://www.multimania.com/nabokos/");
    about.addCredit("David W. Skinner",
                    I18N_NOOP("Provided the 'Microban', 'Sasquatch', 'Mas Sasquatch',\n"
                              "'Sasquatch III', 'Sasquatch IV' and\n"
			      "'Sasquatch V' collections."),
                    "sasquatch@bentonrea.com",
                    "http://users.bentonrea.com/~sasquatch/sokoban/");
    about.addCredit("David Holland",
                    I18N_NOOP("Provided the 'dh1', 'dh2', 'Maelstrom', 'Bagatelle'\n"
                              "and 'Cantrip' collections."),
                    "david@noether.freeserve.co.uk",
                    "http://www.clickfest88.freeserve.co.uk/");
    about.addCredit("François Marques",
                    I18N_NOOP("Provided the 'Kokoban', 'Novoban', 'Numbers',\n"
                              "'Sokoban Online', 'Sokolate', 'Sokompact' and\n"
                              "'Soloban' collections."),
                    "Francois.Marques@freesbee.fr",
                    "http://sokoban.online.fr/");
    about.addCredit("Yoshio Murave",
                    I18N_NOOP("Provided the 'Autogenerated' and 'Handmade' collections."),
                    "yoshio@asahi.email.ne.jp",
                    "http://www.ne.jp/asahi/ai/yoshio/sokoban/main.htm");
    about.addCredit("Jacques Duthen",
                    I18N_NOOP("Provided the 'Dimitry & Yorick' and the 'Sokogen' collections."),
                    "duthen@club-internet.fr",
                    "http://perso.club-internet.fr/duthen/");
    about.addCredit("Evgeniy Grigoriev",
                    I18N_NOOP("Provided the 'Grigr2001' collection."),
                    "grigr@yandex.ru",
                    "http://grigr.narod.ru/sokoban.htm");
    about.addCredit("Martin P Holland",
                    I18N_NOOP("Provided the 'Twisty' collection."),
                    "m.holland@noether.freeserve.co.uk");
    about.addCredit("Jan Borsodi",
                    I18N_NOOP("Created the KSokoban theme and made important suggestions\n"
                              "for the current theme engine."),
                    "jb@ez.no");
    about.addCredit("Anders Widell",
                    I18N_NOOP("Created KSokoban, from which the graphics of the KSokoban\n"
                              "theme are taken and which got me into sokoban."),
                    "awl@hem.passagen.se",
                    "http://hem.passagen.se/awl/ksokoban/");
    about.addCredit("Sascha Nonn",
                    I18N_NOOP("Had various ideas for features of EasySok."),
                    "sascha@pc2a.chemie.uni-dortmund.de",
                    "http://ganter.chemie.uni-dortmund.de/~sascha/");
    about.addCredit("The povray developers",
                    I18N_NOOP("For the excellent free raytracer, which was used to\n"
                              "create almost all graphics for the themes."),
                    0,
                    "http://www.povray.org/");
    about.addCredit("Philip Webb",
                    I18N_NOOP("For reporting various bugs."),
                    "purslow@sympatico.ca",
                    0);
    about.addCredit("Andreas Pour",
                    I18N_NOOP("For various fixes for gcc 3.2."),
                    "pour@mieterra.com",
                    0);

    KCmdLineArgs::init(argc, argv, &about);
    KCmdLineArgs::addCmdLineOptions(options);

    MainWindow * main_window = 0;

    KUniqueApplication::addCmdLineOptions();

    if (!KUniqueApplication::start())
    {
        KWin::setActiveWindow(main_window->winId());

        return 0;
    }

    KUniqueApplication app;

//     KApplication::addCmdLineOptions();
//     KApplication app;

    // Try to make sure we find our resources even when easysok is not
    // installed correctly. This should really go into kstandarddirs.
    QFileInfo exe(exe_name);
    QDir path = exe.dir(true);
    path.cdUp();
    KGlobal::dirs()->addPrefix(path.path());

    Bookmarks::load();

    SolutionHolder::load();

    CollectionHolder::load();

    if (CollectionHolder::numberOfCollections() == 0)
    {
        QString const msg = i18n("Could not find any levels! Installation seems to be corrupt!");
        KMessageBox::error(0, msg);

        return 1;
    }

    ThemeHolder::load();

    if (ThemeHolder::numberOfThemes() == 0)
    {
        QString const msg = i18n("Could not find any themes! Installation seems to be corrupt!");
        KMessageBox::error(0, msg);

        return 1;
    }

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    int times_started = config->readNumEntry("Times started", 0);
    bool user_already_set = !config->readEntry("Current user", "").isEmpty();
    bool user_creation_suggested = config->readBoolEntry("Suggested user creation", user_already_set);

    bool first_ksokoban_bookmark_found = false;
    int ksokoban_bookmarks_imported = 0;

    if (times_started == 0)
    {
        for (int i = 1; i <= 10; ++i)
        {
            if (Bookmarks::hasKSokobanBookmark(i))
            {
                if (!first_ksokoban_bookmark_found)
                {
                    QString const msg = i18n("Do you want to import your KSokoban bookmarks?");

                    if (KMessageBox::questionYesNo(0, msg) == KMessageBox::No)
                    {
                        break;
                    }

                    first_ksokoban_bookmark_found = true;
                }

                int free_slot = 0;

                while (Bookmarks::hasBookmark(free_slot))
                {
                    ++free_slot;
                }

                if (Bookmarks::importKSokobanBookmark(i, free_slot))
                {
                    ++ksokoban_bookmarks_imported;
                }
            }
        }

        if (first_ksokoban_bookmark_found)
        {
            if (ksokoban_bookmarks_imported == 0)
            {
                KMessageBox::information(0, i18n("No KSokoban bookmarks could be imported!"));
            }
            else
            {
                QString msg = i18n("Imported %1 KSokoban bookmark(s)");
                msg = msg.arg(ksokoban_bookmarks_imported);

                KMessageBox::information(0, msg);
            }
        }
    }

    if (!user_creation_suggested)
    {
        if (KMessageBox::questionYesNo(0, i18n("In order to compare you solutions with that of other "
                                               "players,\nyou have to create a user on a highscore server.\n"
                                               "This takes only a few seconds and is strongly "
                                               "recommended.\nIf you are not connected to the internet, "
                                               "you will want to skip this step.\nYou can also create a "
                                               "user later on."), QString::null, i18n("Create User"),
                                       i18n("Skip")) == KMessageBox::Yes)
        {
            CreateUserDialog dialog(0);

            dialog.exec();
        }
    }

    config->setGroup("");
    config->writeEntry("Times started", times_started + 1);
    config->writeEntry("Suggested user creation", true);

    main_window = new MainWindow();

    app.setMainWidget(main_window);
    main_window->show();

    app.exec();

    CollectionHolder::save();

    SolutionHolder::save();

    Bookmarks::save();

    return 0;
}
