/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "move_optimizer.h"

#include <cassert>

#include "map.h"




MoveOptimizer::MoveOptimizer() :
    m_number_of_moves(0),
    m_number_of_pushes(0)
{
}


MoveOptimizer::MoveOptimizer(Map const & map, Movements const & moves)
{
    optimize(map, moves);
}


void MoveOptimizer::optimize(Map const & map, Movements const & moves)
{
    m_number_of_pushes = 0;
    m_number_of_moves = 0;

    if (moves.isEmpty())
    {
        return;
    }

    Movements expanded_moves = map.expandMoves(moves, false);
    assert(!expanded_moves.isEmpty());
    m_moves = map.collapseMoves(expanded_moves);
    expanded_moves = map.expandMoves(m_moves, false);
    expanded_moves.setToFirstPosition();

    while (expanded_moves.hasNextMove())
    {
        if (expanded_moves.nextMove().stonePushed())
        {
            ++m_number_of_pushes;
        }
    }

    m_number_of_moves = expanded_moves.numberOfMoves();
}


Movements const & MoveOptimizer::moves() const
{
    return m_moves;
}


int MoveOptimizer::numberOfMoves() const
{
    return m_number_of_moves;
}


int MoveOptimizer::numberOfPushes() const
{
    return m_number_of_pushes;
}
