/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_MOVE_OPTIMIZER_INC_GUARD_H
#define EASYSOK_MOVE_OPTIMIZER_INC_GUARD_H


#include "movements.h"
#include "optimizer.h"


class Map;




/**
 * This class lets you optimize the number of moves for a given sequence of moves.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 * @see Move
 */

class MoveOptimizer : public Optimizer
{

public:

    /**
     * Constructs the empty object.
     */

    MoveOptimizer();


    /**
     * Contructs the object and optimizes the number of moves.
     *
     * @param map The start map of the moves.
     * @param moves The moves to optimize.
     */

    MoveOptimizer(Map const & map, Movements const & moves);


    virtual void optimize(Map const & map, Movements const & moves);
    virtual Movements const & moves() const;
    virtual int numberOfMoves() const;
    virtual int numberOfPushes() const;


private:

    /**
     * The optimized moves.
     */

    Movements m_moves;


    /**
     * The number of atomic moves.
     */

    int m_number_of_moves;


    /**
     * The number of atomic pushes.
     */

    int m_number_of_pushes;
};


#endif
