/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_OPTIMIZER_INC_GUARD_H
#define EASYSOK_OPTIMIZER_INC_GUARD_H


class Map;
class Movements;




/**
 * The base class of objects which let you optimize moves, pushes etc.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 * @see Move
 */

class Optimizer
{

public:

    /**
     * The virtual destructor.
     */

    virtual ~Optimizer();


    /**
     * Optimizes the moves of the given map.
     *
     * @param map The start map of the moves.
     * @param moves The moves to optimize.
     */

    virtual void optimize(Map const & map, Movements const & moves) = 0;


    /**
     * Returns the optimized moves.
     *
     * Note that the moves are not atomic, but as compact as possible.
     */

    virtual Movements const & moves() const = 0;


    /**
     * Returns the optimized number of atomic moves.
     */

    virtual int numberOfMoves() const = 0;


    /**
     * Returns the optimized number of atomic pushes.
     */

    virtual int numberOfPushes() const = 0;
};


#endif
