/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_PIECE_IMAGE_INC_GUARD_H
#define EASYSOK_PIECE_IMAGE_INC_GUARD_H


#include <vector>

#include <qimage.h>
#include <qpoint.h>

#include "piece_image_effect.h"
#include "piece_image_layer.h"


class QDomElement;




/**
 * This class represents a piece image which consists of piece image layers.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class PieceImage
{

public:

    /**
     * Constructs a piece image from a dom element.
     *
     * @param dom_element The dom element to use.
     */

    PieceImage(QDomElement const & dom_element);


    /**
     * Returns the image of the given native size.
     */

    QImage createImage() const;


    /**
     * Returns the x-offset of the piece image.
     */

    double xOffset() const;


    /**
     * Returns the y-offset of the piece image.
     */

    double yOffset() const;


    /**
     * Returns the native size of the image created in createImage().
     */

    int size() const;


    /**
     * Returns true if the two piece images are equal.
     *
     * @param other_piece_image The other piece image.
     */

    bool operator == (PieceImage const & other_piece_image) const;


private:

    /**
     * The global effect.
     */

    PieceImageEffect m_effect;


    /**
     * The layers used.
     */

    std::vector<PieceImageLayer> m_layers;


    /**
     * The native size.
     */

    int m_size;


    /**
     * The x-offset.
     */

    double m_x_offset;


    /**
     * The y-offset.
     */

    double m_y_offset;
};


#endif
