/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "piece_image_layer.h"

#include <cassert>

#include <qdom.h>

#include <kglobal.h>
#include <kstddirs.h>

#include "dom_helper.h"




PieceImageLayer::PieceImageLayer(QDomElement const & dom_element)
{
    assert(dom_element.tagName() == "Layer");
    assert(dom_element.childNodes().count() <= 1);

    m_color = DomHelper::getColor(dom_element);
    m_image = dom_element.attribute("image", "");

    QDomNodeList childs = dom_element.childNodes();

    if (childs.count() >= 1)
    {
        QDomNode node = childs.item(0);

        if (node.isElement())
        {
            QDomElement effect_element = node.toElement();

            if (effect_element.tagName() == "Effect")
            {
                m_effect = PieceImageEffect(effect_element);
            }
        }
    }
}


QImage PieceImageLayer::createImage(int size) const
{
    bool uses_image = !m_image.isEmpty();

    if (uses_image)
    {
        QString filename = KGlobal::dirs()->findResource("data", "easysok/" + m_image);

        if (filename.isEmpty())
        {
            filename = m_image;
        }

        QImage image;
        image.load(filename);

        if ( (image.width() != 0) && (image.height() != 0) )
        {
            image = image.convertDepth(32);

            return m_effect.apply(image);
        }
    }

    QImage image(size, size, 32);
    image.fill(m_color);
    image.setAlphaBuffer(true);

    return m_effect.apply(image);
}


bool PieceImageLayer::operator == (PieceImageLayer const & other_layer) const
{
    return ( (m_color == other_layer.m_color) && (m_image == other_layer.m_image) &&
             (m_effect == other_layer.m_effect) );

}
