/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_PIECE_IMAGE_LAYER_INC_GUARD_H
#define EASYSOK_PIECE_IMAGE_LAYER_INC_GUARD_H


#include <qcolor.h>
#include <qimage.h>

#include "piece_image_effect.h"


class QDomElement;




/**
 * This class represents one layer used to construct a piece image.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class PieceImageLayer
{

public:

    /**
     * Reads a image layer from a dom element.
     *
     * @param dom_element The dom element to use.
     */

    PieceImageLayer(QDomElement const & dom_element);


    /**
     * Returns the image.
     *
     * @param size The size of the overall piece image.
     */

    QImage createImage(int size) const;


    /**
     * Returns true, if the two layers are equal.
     *
     * @param other_layer The other layer.
     */

    bool operator == (PieceImageLayer const & other_layer) const;


private:

    /**
     * The background color.
     */

    QRgb m_color;


    /**
     * The filename of the image to use.
     */

    QString m_image;


    /**
     * The image effect.
     */

    PieceImageEffect m_effect;
};


#endif
