/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "proxy_suggestor.h"

#include <stdlib.h>

#include <qdir.h>
#include <qfile.h>
#include <qstring.h>
#include <qtextstream.h>

#include <ksimpleconfig.h>
#include <kurl.h>


void ProxySuggestor::suggestProxy(QString & server, int & port)
{
    server = "";
    port = 8080;

    suggestProxyFromEnv(server, port);

    suggestKonquerorProxy(server, port);

    if (!server.isEmpty())
    {
        return;
    }

    suggestNetscapeTypeProxy(QDir::home().path() + "/.netscape/preferences.js", server, port);

    if (!server.isEmpty())
    {
        return;
    }

    QString user = getenv("USER");

    if (!user.isEmpty())
    {
        QDir first_dir(QDir::home().path() + "/.mozilla/" + user);
        QStringList dirs = first_dir.entryList(QDir::Dirs | QDir::Readable);
        int nr_of_dirs = dirs.count();

        for (int i = 0; i < nr_of_dirs; ++i)
        {
            QString act_dir = QDir::home().path() + "/.mozilla/" + user + "/" + dirs[i] + "/prefs.js";
            suggestNetscapeTypeProxy(act_dir, server, port);
        }
    }

    if (!server.isEmpty())
    {
        return;
    }

    suggestNetscapeTypeProxy(QDir::home().path() + "/.galeon/mozilla/galeon/prefs.js", server, port);

    if (!server.isEmpty())
    {
        return;
    }

    suggestOperaProxy(server, port);
}


void ProxySuggestor::suggestKonquerorProxy(QString & server, int & port)
{
    KSimpleConfig config("kioslaverc", true);
    config.setGroup("Proxy Settings");

    KURL proxy(config.readEntry("httpProxy", ""));

    server = proxy.host();

    if (!server.isEmpty())
    {
        port = static_cast<int> (proxy.port());
    }
}


void ProxySuggestor::suggestNetscapeTypeProxy(QString const & prefs_file, QString & server, int & port)
{
    QFile file(prefs_file);

    if (!file.open(IO_ReadOnly))
    {
        return;
    }

    QTextStream stream(&file);

    while (!stream.atEnd())
    {
        QString line = stream.readLine();

        if (line.find("user_pref(\"network.proxy.http\"") == 0)
        {
            QStringList parts = QStringList::split("\"", line);

            if (parts.count() == 5)
            {
                server = parts[3];
            }
        }

        if (line.find("user_pref(\"network.proxy.http_port\"") == 0)
        {
            QStringList parts = QStringList::split(", ", line);

            if (parts.count() == 2)
            {
                parts = QStringList::split(")", parts[1]);
                port = parts[0].toInt();
            }
        }
    }
}


void ProxySuggestor::suggestOperaProxy(QString & server, int & port)
{
    KSimpleConfig config(QDir::home().path() + "/.opera/opera.ini", true);
    config.setGroup("Proxy");

    QString raw_proxy = config.readEntry("HTTP Server", "");

    suggestProxyFromURL(raw_proxy, server, port);
}


void ProxySuggestor::suggestProxyFromEnv(QString & server, int & port)
{
    char const * http_proxy = getenv("HTTP_PROXY");

    if (!http_proxy)
    {
        http_proxy = getenv("HTTP_proxy");
    }

    if (!http_proxy)
    {
        http_proxy = getenv("http_proxy");
    }

    if (http_proxy)
    {
        suggestProxyFromURL(http_proxy, server, port);
    }
}


void ProxySuggestor::suggestProxyFromURL(QString const & url, QString & server, int & port)
{
    if (!url.isEmpty())
    {
        QStringList parts = QStringList::split(":", url);

        if (parts.count() == 2)
        {
            server = parts[0];
            port = parts[1].toInt();
        }
    }
}
