/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_PROXY_SUGGESTOR_INC_GUARD_H
#define EASYSOK_PROXY_SUGGESTOR_INC_GUARD_H


class QString;




/**
 * Tries to suggest a proxy port.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ProxySuggestor
{

public:

    /**
     * Suggests a proxy by searching if the user has already set one in a web browser.
     *
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestProxy(QString & server, int & port);


private:

    /**
     * Suggests a proxy by searching if the user has already set one in konqueror.
     *
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestKonquerorProxy(QString & server, int & port);


    /**
     * Suggests a proxy by searching if the user has already set one netscape/mozilla/galeon.
     *
     * @param prefs_file The filename of the preferences.
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestNetscapeTypeProxy(QString const & prefs_file, QString & server, int & port);


    /**
     * Suggests a proxy by searching if the user has already set one in opera.
     *
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestOperaProxy(QString & server, int & port);


    /**
     * Suggests a proxy by using the HTTP_PROXY environment variable.
     *
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestProxyFromEnv(QString & server, int & port);


    /**
     * Suggests a proxy by parsing a proxy url.
     *
     * @parsing url The proxy url.
     * @param Here we set the proxy server name.
     * @param Here we set the proxy port.
     */

    static void suggestProxyFromURL(QString const & url, QString & server, int & port);
};


#endif
