/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_QUERY_DIALOG_INC_GUARD_H
#define EASYSOK_QUERY_DIALOG_INC_GUARD_H


#include <qmessagebox.h>
#include <qstring.h>

#include "server_connector.h"


class KURL;
class QSocket;




/**
 * The dialog shown when we setup (add or change) the user.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class QueryDialog : public QMessageBox
{
    Q_OBJECT

public:

    /**
     * Creates the dialog.
     *
     * @param caption The caption of the dialog.
     * @param text The text of the dialog.
     * @param server The url of the server.
     * @param proxy The host of the proxy to use (empty if we don't use one).
     * @param proxy_port The port of the proxy.
     * @param script The script to use.
     * @param query The query to use.
     * @param parent The parent of the dialog.
     */

    QueryDialog(QString const & caption, QString const & text, KURL const & server,
                QString const & proxy, int proxy_port, QString const & script,
                QString const & query, QWidget * parent = 0);


    /**
     * Returns the result of the query.
     */

    ServerConnector::Result result() const;


    /**
     * Returns a human readable version of the result.
     */

    QString resultText() const;


    /**
     * Returns the data from the query.
     */

    QString data() const;


    /**
     * Returns the version of the server.
     */

    int version() const;


private:

    /**
     * The server connector.
     */

    ServerConnector * m_server_connector;

};


#endif
