/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_REORDER_LIST_VIEW_INC_GUARD_H
#define EASYSOK_REORDER_LIST_VIEW_INC_GUARD_H


#include <klistview.h>


/**
 * The list view used in ReorderListDialog.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ReorderListView : public KListView
{
    Q_OBJECT

public:

    /**
     * Creates the list view with all collections/level of the collection holder.
     *
     * @param parent The parent of the dialog.
     * @param name The internal name of the dialog.
     */

    ReorderListView(QWidget * parent = 0, char const * name = 0);


    /**
     * Reorders the levels/collections in the CollectionHolder to reflect
     * the order in the list view.
     *
     * @return True, if the update was not cancelled.
     */

    bool updateCollectionHolder();


protected:

    /**
     * Here we ensure that levels are dropped only in collections and
     * collections not in other collections.
     *
     * @parent event The drop event.
     */

    virtual bool acceptDrag (QDropEvent * event) const;


protected slots:

    /**
     * Used to deselect all items when moved.
     */

    void afterMove();
};


#endif
