/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "select_date_dialog.h"

#include <qpushbutton.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <kdatepik.h>
#include <klocale.h>




SelectDateDialog::SelectDateDialog(QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Set A Date"), Ok | Cancel | Help, Ok, true)
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    QVBox * page = makeVBoxMainWidget();
    page->setSpacing(10);

    QDate date = config->readDateTimeEntry("Date of solutions", 0).date();

    m_date = new KDatePicker(page, date);

    QPushButton * button = new QPushButton(i18n("Set to current date"), page);
    connect(button, SIGNAL(clicked()), this, SLOT(setCurrentDate()));

    setHelp("select-date-dialog");
}


SelectDateDialog::~SelectDateDialog()
{
    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    config->writeEntry("Date of solutions", QDateTime(date()));
}


QDate SelectDateDialog::date() const
{
    return m_date->getDate();
}


void SelectDateDialog::setCurrentDate()
{
    m_date->setDate(QDate::currentDate());
}
