/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "set_user_dialog.h"

#include <qfont.h>
#include <qfontmetrics.h>
#include <qlabel.h>
#include <qstringlist.h>
#include <qvbox.h>

#include <kapp.h>
#include <kconfig.h>
#include <klistbox.h>
#include <klocale.h>



SetUserDialog::SetUserDialog(QWidget * parent, char const * name) :
    KDialogBase(parent, name, true, i18n("Set User"), Ok | Cancel | Help, Ok, true)
{
    QVBox * page = makeVBoxMainWidget();

    KConfig * config = KApplication::kApplication()->config();
    config->setGroup("");

    QStringList nicknames = config->readListEntry("Nicknames");

    if (nicknames.isEmpty())
    {
        m_nicknames = 0;

        new QLabel(i18n("You first must create or import a user!"), page);
        enableButtonOK(false);
    }
    else
    {
        new QLabel(i18n("Select the user"), page);

        m_nicknames = new KListBox(page);
        m_nicknames->insertStringList(nicknames);

        QString act_user = config->readEntry("Current user", "");

        if (!act_user.isEmpty())
        {
            int index = nicknames.findIndex(act_user);

            if (index != -1)
            {
                m_nicknames->setCurrentItem(index);
                m_nicknames->ensureCurrentVisible();
            }
        }

        m_nicknames->setMinimumHeight(QFontMetrics(QFont()).height() * 5);
    }

    setHelp("set-user-dialog");
}


void SetUserDialog::slotOk()
{
    if (m_nicknames != 0)
    {
        KConfig * config = KApplication::kApplication()->config();
        config->setGroup("");

        QString nickname = m_nicknames->currentText();
        config->writeEntry("Current user", nickname);
    }

    KDialogBase::slotOk();
}
