/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "solution_annotate_dialog.h"

#include <cassert>
#include <vector>

#include <qstring.h>
#include <qvbox.h>

#include <klineeditdlg.h>
#include <klocale.h>

#include "compressed_map.h"
#include "solution_holder.h"
#include "solution_list_view.h"




SolutionAnnotateDialog::SolutionAnnotateDialog(CompressedMap const & map, QWidget * parent,
                                               const char * name) :
    KDialogBase(parent, name, true, i18n("Annotate solutions"), Ok | User1 | Cancel,
                Ok, true, i18n("Annotate"))
{
    m_index = SolutionHolder::getIndexForMap(map);
    assert(m_index != -1);

    m_list_view = new SolutionListView(m_index, makeVBoxMainWidget());

    connect(m_list_view, SIGNAL(clickedSolution(int)), this, SLOT(solutionSelected(int)));
}


SolutionAnnotateDialog::SolutionAnnotateDialog(int index, QWidget * parent, const char * name) :
    KDialogBase(parent, name, true, i18n("Annotate solutions"), Ok | User1 | Cancel, Ok,
                true, i18n("Annotate"))
{
    assert(index != -1);
    m_list_view = new SolutionListView(index, makeVBoxMainWidget());

    connect(m_list_view, SIGNAL(clickedSolution(int)), this, SLOT(solutionSelected(int)));

    m_index = index;
}


void SolutionAnnotateDialog::solutionSelected(int index)
{
    annotateSolution(index);
}


void SolutionAnnotateDialog::slotUser1()
{
    std::vector<int> selected = m_list_view->selectedSolutions();

    if (!selected.empty())
    {
        annotateSolution(selected.front());
    }

    KDialogBase::slotUser1();
}


void SolutionAnnotateDialog::slotOk()
{
    int const number_of_solutions = SolutionHolder::numberOfSolutions(m_index);
    assert(number_of_solutions > 0);

    for (int i = 0; i < number_of_solutions; ++i)
    {
        SolutionHolder::changeSolutionInfo(m_index, i, m_list_view->annotation(i));
    }

    KDialogBase::slotOk();
}


void SolutionAnnotateDialog::annotateSolution(int solution)
{
    KLineEditDlg dialog(i18n("Enter the annotation"), m_list_view->annotation(solution), this);

    if (dialog.exec())
    {
        m_list_view->setAnnotation(solution, dialog.text());
    }
}
