/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "solution_delete_dialog.h"

#include <cassert>
#include <vector>

#include <qstring.h>
#include <qvbox.h>

#include <klocale.h>

#include "compressed_map.h"
#include "solution_holder.h"
#include "solution_list_view.h"




SolutionDeleteDialog::SolutionDeleteDialog(CompressedMap const & map, QWidget * parent, const char * name) :
    KDialogBase(parent, name, true, i18n("Delete solutions"), Ok | User1 | User2 | Cancel | Help,
                Ok, true, i18n("Delete"), i18n("Undelete"))
{
    m_index = SolutionHolder::getIndexForMap(map);
    assert(m_index != -1);

    m_list_view = new SolutionListView(m_index, makeVBoxMainWidget());
    m_list_view->setSelectionMode(QListView::Multi);

    setHelp("solution-delete-dialog");
}


SolutionDeleteDialog::SolutionDeleteDialog(int index, QWidget * parent, const char * name) :
    KDialogBase(parent, name, true, i18n("Delete solutions"), Ok | User1 | User2 | Cancel, Ok,
                true, i18n("Delete"), i18n("Undelete"))
{
    m_index = index;
    assert(m_index != -1);

    m_list_view = new SolutionListView(m_index, makeVBoxMainWidget());
    m_list_view->setSelectionMode(QListView::Multi);

    setHelp("solution-delete-dialog");
}


void SolutionDeleteDialog::slotUser1()
{
    std::vector<int> selected = m_list_view->selectedSolutions();
    int const number_of_selections = static_cast<int> (selected.size());

    for (int i = 0; i < number_of_selections; ++i)
    {
        m_list_view->setHidden(selected[i], true);
    }
}


void SolutionDeleteDialog::slotUser2()
{
    int const number_of_solutions = m_list_view->numberOfSolutions();

    for (int i = 0; i < number_of_solutions; ++i)
    {
        m_list_view->setHidden(i, false);
    }
}


void SolutionDeleteDialog::slotOk()
{
    for (int i = m_list_view->numberOfSolutions() - 1; i >= 0; --i)
    {
        if (m_list_view->isHidden(i))
        {
            SolutionHolder::deleteSolution(m_index, i);
        }
    }

    accept();
}
