/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_SOLUTION_OPTIMIZE_DIALOG_INC_GUARD_H
#define EASYSOK_SOLUTION_OPTIMIZE_DIALOG_INC_GUARD_H


#include <vector>

#include <kdialogbase.h>

#include "movements.h"


class CompressedMap;
class SolutionListView;




/**
 * Lets the user optimize solutions.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class SolutionOptimizeDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Contructs the object.
     *
     * Note that the map <e>must</e> have a solution.
     *
     * @param compressed_map The compressed map of the level.
     * @param opt_pushes If true, we optimize pushes and moves and if false only moves.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    SolutionOptimizeDialog(CompressedMap const & map, bool opt_pushes,
                           QWidget * parent = 0, const char * name = 0);


    /**
     * @overload
     */

    SolutionOptimizeDialog(int index, bool opt_pushes, QWidget * parent = 0, const char * name = 0);


protected slots:

    /**
     * Called when the user selected optimize.
     */

    void slotUser1();


    /**
     * Called when a ok is clicked.
     */

    void slotOk();


private:

    /**
     * The compressed map.
     */

    CompressedMap const & m_map;


    /**
     * The list view with the solution data.
     */

    SolutionListView * m_list_view;


    /**
     * Here we store 1, if the solutions was optimized.
     */

    std::vector<int> m_optimized;


    /**
     * Here we store the moves.
     */

    std::vector<Movements> m_moves;


    /**
     * The index of the map.
     */

    int m_index;


    /**
     * If true, we optimzed pushes.
     */

    bool m_opt_pushes;
};



#endif
