/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "solution_select_dialog.h"

#include <cassert>
#include <vector>

#include <qstring.h>
#include <qvbox.h>

#include <klocale.h>

#include "compressed_map.h"
#include "solution_holder.h"
#include "solution_list_view.h"



SolutionSelectDialog::SolutionSelectDialog(CompressedMap const & map, bool can_select,
                                           QWidget * parent, const char *name) :
    KDialogBase(parent, name, true, can_select ? i18n("Load a solution") : i18n("Solutions"),
                can_select ? Ok | Cancel : Cancel, can_select ? Cancel : Ok, true),
    m_selected_solution(0)
{
    m_list_view = new SolutionListView(map, makeVBoxMainWidget());

    connect(m_list_view, SIGNAL(clickedSolution(int)), this, SLOT(solutionSelected(int)));
}


SolutionSelectDialog::SolutionSelectDialog(int index, bool can_select, QWidget * parent, const char * name) :
    KDialogBase(parent, name, true, can_select ? i18n("Load a solution") : i18n("Solutions"),
                can_select ? Ok | Cancel : Cancel, can_select ? Cancel : Ok, true),
    m_selected_solution(0)
{
    m_list_view = new SolutionListView(index, makeVBoxMainWidget());

    connect(m_list_view, SIGNAL(clickedSolution(int)), this, SLOT(solutionSelected(int)));
}


int SolutionSelectDialog::selectedSolution()
{
    return m_selected_solution;
}


void SolutionSelectDialog::solutionSelected(int index)
{
    m_selected_solution = index;
    accept();
}


void SolutionSelectDialog::slotOk()
{
    std::vector<int> selected = m_list_view->selectedSolutions();

    if (!selected.empty())
    {
        m_selected_solution = selected.front();
    }

    KDialogBase::slotOk();
}
