/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_SOLUTION_SELECT_DIALOG_INC_GUARD_H
#define EASYSOK_SOLUTION_SELECT_DIALOG_INC_GUARD_H


#include <kdialogbase.h>


class CompressedMap;
class SolutionListView;




/**
 * Lets the user select a solution.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class SolutionSelectDialog : public KDialogBase
{
    Q_OBJECT

public:

    /**
     * Contructs the object.
     *
     * Note that the map <e>must</e> have a solution.
     *
     * @param compressed_map The compressed map of the level.
     * @param can_select If true, a solution can be selected.
     * @param parent The parent widget.
     * @param name The internal name.
     */

    SolutionSelectDialog(CompressedMap const & map, bool can_select,
                         QWidget * parent = 0, const char * name = 0);


    /**
     * @overload
     */

    SolutionSelectDialog(int index, bool can_select, QWidget * parent = 0, const char * name = 0);


    /**
     * Returns the selected solution.
     */

    int selectedSolution();


public slots:

    /**
     * Called when the user selected a solution.
     *
     * @parent index The index of the selected solution.
     */

    void solutionSelected(int index);


protected slots:

    /**
     * Called when a ok is clicked.
     */

    void slotOk();


private:

    /**
     * The list view with the solution data.
     */

    SolutionListView * m_list_view;


    /**
     * The selected solution
     */

    int m_selected_solution;
};



#endif
