/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_SOLVER_DIALOG_INC_GUARD_H
#define EASYSOK_SOLVER_DIALOG_INC_GUARD_H


#include <qmessagebox.h>
#include <qstring.h>

#include "map.h"

class QTimer;
class Solver;




/**
 * A dialog for the solver.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class SolverDialog : public QMessageBox
{
    Q_OBJECT

public:

    /**
    * Creates the dialog.
    *
    * @param map The map to solve.
    * @param parent The parent of the dialog.
    * @param name The internal name of the dialog.
    */

    SolverDialog(Map const & map, QWidget * parent = 0, char const * name = 0);


    /**
     * Releases all resources.
     */

    virtual ~SolverDialog();


    /**
     * Returns the solver.
     */

    Solver const * solver() const;


    /**
     * Returns the number of positions examined as a human readable string.
     */

    QString positionsExaminedAsText() const;


private slots:

    /**
     * Initialzes the solver.
     */

    void prepareSolver();


    /**
     * Performs the solve.
     */

    void performSolve();


private:

    /**
     * The solver.
     */

    Solver * m_solver;


    /**
     * The timer used.
     */

    QTimer * m_timer;


    /**
     * The number of positions per step.
     */

    int m_positions_per_step;


    /**
     * The number of positions beyond the millions.
     */

    int m_steps_rest;


    /**
     * The number of positions in million.
     */

    int m_steps_million;
};


#endif
