/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_THEME_FILE_INC_GUARD_H
#define EASYSOK_THEME_FILE_INC_GUARD_H


#include <qcolor.h>
#include <qfile.h>
#include <qstring.h>
#include <qtextstream.h>




/**
 * This class makes handling theme files easier.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ThemeFile
{

public:

    /**
     * Creates the object.
     *
     * The theme data is read from the given file.
     *
     * @param filename The filename of the theme file.
     */

    ThemeFile(QString const & filename);


    /**
     * Returns true, if the theme file is valid (could be opened).
     */

    bool isValid() const;


    /**
     * Reads a color from a theme file.
     */

    QRgb readColor();


    /**
     * Reads a text string from the theme file.
     */

    QString readString();


    /**
     * Reads a text string from the theme file.
     *
     * @param expected The expected text. If it is not found, an error message will be displayed.
     */

    QString readString(QString const & expected);


    /**
     * Reads a text string from the theme file.
     *
     * @param expected1 The first alternative expected.
     * @param expected2 The second alternative expected. If neither this nor expected1 is found,
     *                  an error message is displayed.
     */

    QString readString(QString const & expected1, QString const & expected2);


    /**
     * Reads a text string from the theme file.
     *
     * @param expected1 The first alternative expected.
     * @param expected2 The second alternative expected.
     * @param expected3 The third alternative expected. If neither this nor expected1 or expected2 is found,
     *                  an error message is displayed.
     */

    QString readString(QString const & expected1, QString const & expected2, QString const & expected3);


    /**
     * Reads an integer from the theme file.
     */

    int readInt();


    /**
     * Reads an double from the theme file.
     */

    double readDouble();


    /**
     * Returns the actual line number.
     */

    int lineNr() const;


    /**
     * Return the filename of the theme file.
     */

    QString const & filename() const;


private:

    /**
     * The filename.
     */

    QString m_filename;


    /**
     * The actual line number.
     */

    int m_line_nr;


    /**
     * The file to use.
     */

    QFile m_file;


    /**
     * The stream to use.
     */

    QTextStream m_stream;
};


#endif
