/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "theme_holder.h"

#include <cassert>

#include <qdom.h>
#include <qfile.h>
#include <qstring.h>
#include <qstringlist.h>

#include <kglobal.h>
#include <kstddirs.h>

#include "theme.h"




std::vector<Theme *> ThemeHolder::s_themes;
bool ThemeHolder::s_initialized = false;


void ThemeHolder::load()
{
    assert(s_initialized == false);

    s_initialized = true;

    QStringList files = KGlobal::dirs()->findAllResources("data", "easysok/themes/*.xml");
    getThemes(files);
}


int ThemeHolder::numberOfThemes()
{
    assert(s_initialized = true);

    return static_cast<int> (s_themes.size());
}


int ThemeHolder::indexFromName(QString const & name)
{
    assert(s_initialized = true);

    int const number_of_themes = numberOfThemes();

    for (int i = 0; i < number_of_themes; ++i)
    {
        if (theme(i)->name() == name)
        {
            return i;
        }
    }

    return -1;
}


Theme * ThemeHolder::theme(int index)
{
    assert(s_initialized = true);
    assert(index >= 0);
    assert(index < numberOfThemes());

    return s_themes[index];
}


void ThemeHolder::getThemes(QStringList const & files)
{
    QStringList::ConstIterator it = files.begin();
    QStringList::ConstIterator const end_it = files.end();

    for (; it != end_it; ++it)
    {
        QFile file(*it);

        if (!file.open(IO_ReadOnly))
        {
            continue;
        }

        QDomDocument dom_document;

        if (!dom_document.setContent(&file))
        {
            continue;
        }

        if (dom_document.doctype().name() != "EasySokTheme")
        {
            continue;
        }

        s_themes.push_back(new Theme(dom_document.documentElement()));
    }
}
