/*
 *   EasySok --- A(nother) sokoban game for KDE.
 *
 *   Copyright (C) 2001 by Ralf Schmelter (ralf.schmelter@t-online.de).
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2 as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef EASYSOK_THEME_HOLDER_INC_GUARD_H
#define EASYSOK_THEME_HOLDER_INC_GUARD_H


#include <vector>


class QString;
class QStringList;
class Theme;




/**
 * This class holds themes.
 *
 * @author Ralf Schmelter (ralf.schmelter@t-online.de).
 * @version 0.2
 */

class ThemeHolder
{

public:

    /**
     * Loads the themes.
     */

    static void load();


    /**
     * Returns the number of themes.
     */

    static int numberOfThemes();


    /**
     * Returns the index of the theme with the given name or -1 if it does not exists.
     *
     * @param name The name of the theme.
     */

    static int indexFromName(QString const & name);


    /**
     * Returns a pointer to the given theme.
     *
     * @param index The index of the theme.
     */

    static Theme * theme(int index);


private:

    /**
     * Loads the themes from the given theme-files.
     *
     * @param files The files from which to load the themes.
     */

    static void getThemes(QStringList const & files);


    /**
     * The themes.
     */

    static std::vector<Theme *> s_themes;


    /**
     * If true, load was called.
     */

    static bool s_initialized;
};


#endif
